@@ -260,27 +260,7 @@ func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 		CheckForbiddenStatus(t, resp)
 	})
 
-	t.Run("mysql database not supported", func(t *testing.T) {
-		// Skip this test unless running with MySQL driver
-		if *th.App.Config().SqlSettings.DriverName != model.DatabaseDriverMysql {
-			t.Skip("Skipping test - only runs with MySQL driver")
-		}
-
-		licenseManagerMock := &mocks.LicenseInterface{}
-		licenseManagerMock.On("CanStartTrial").Return(true, nil).Once()
-		th.App.Srv().Platform().SetLicenseManager(licenseManagerMock)
-
-		resp, err := th.SystemAdminClient.RequestTrialLicenseWithExtraFields(context.Background(), validTrialRequest)
-		CheckErrorID(t, err, "api.license.request-trial.mysql.app_error")
-		CheckBadRequestStatus(t, resp)
-	})
-
 	t.Run("trial license user count less than current users", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		license := model.NewTestLicense()
 		license.Features.Users = model.NewPointer(nUsers)
 		licenseJSON, jsonErr := json.Marshal(license)
@@ -317,11 +297,6 @@ func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 	})
 
 	t.Run("returns status 451 when it receives status 451", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		license := model.NewTestLicense()
 		license.Features.Users = model.NewPointer(nUsers)
 		licenseJSON, jsonErr := json.Marshal(license)
@@ -352,11 +327,6 @@ func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 	})
 
 	t.Run("returns status 400 if request is a mix of legacy and new fields", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		validTrialRequest.CompanyCountry = ""
 		validTrialRequest.Users = 100
 		defer func() { validTrialRequest.CompanyCountry = "US" }()
@@ -396,12 +366,8 @@ func TestRequestTrialLicenseWithExtraFields(t *testing.T) {
 	})
 
 	th.App.Srv().Platform().SetLicenseManager(nil)
-	t.Run("trial license should fail if LicenseManager is nil", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
 
+	t.Run("trial license should fail if LicenseManager is nil", func(t *testing.T) {
 		resp, err := th.SystemAdminClient.RequestTrialLicenseWithExtraFields(context.Background(), validTrialRequest)
 		CheckErrorID(t, err, "api.license.upgrade_needed.app_error")
 		CheckForbiddenStatus(t, resp)
@@ -425,27 +391,7 @@ func TestRequestTrialLicense(t *testing.T) {
 		CheckForbiddenStatus(t, resp)
 	})
 
-	t.Run("mysql database not supported", func(t *testing.T) {
-		// Skip this test unless running with MySQL driver
-		if *th.App.Config().SqlSettings.DriverName != model.DatabaseDriverMysql {
-			t.Skip("Skipping test - only runs with MySQL driver")
-		}
-
-		licenseManagerMock := &mocks.LicenseInterface{}
-		licenseManagerMock.On("CanStartTrial").Return(true, nil).Once()
-		th.App.Srv().Platform().SetLicenseManager(licenseManagerMock)
-
-		resp, err := th.SystemAdminClient.RequestTrialLicense(context.Background(), 1000)
-		CheckErrorID(t, err, "api.license.request-trial.mysql.app_error")
-		CheckBadRequestStatus(t, resp)
-	})
-
 	t.Run("trial license invalid JSON", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		// the JSON is invalid because it is missing a closing brace
 
 		licenseManagerMock := &mocks.LicenseInterface{}
@@ -458,11 +404,6 @@ func TestRequestTrialLicense(t *testing.T) {
 	})
 
 	t.Run("trial license user count less than current users", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		nUsers := 1
 		license := model.NewTestLicense()
 		license.Features.Users = model.NewPointer(nUsers)
@@ -498,11 +439,6 @@ func TestRequestTrialLicense(t *testing.T) {
 	})
 
 	t.Run("returns status 451 when it receives status 451", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		nUsers := 1
 		license := model.NewTestLicense()
 		license.Features.Users = model.NewPointer(nUsers)
@@ -535,11 +471,6 @@ func TestRequestTrialLicense(t *testing.T) {
 
 	th.App.Srv().Platform().SetLicenseManager(nil)
 	t.Run("trial license should fail if LicenseManager is nil", func(t *testing.T) {
-		// Skip this test when MySQL is configured as it hits the MySQL check first
-		if *th.App.Config().SqlSettings.DriverName == model.DatabaseDriverMysql {
-			t.Skip("Skipping test - MySQL does not support trial licenses")
-		}
-
 		resp, err := th.SystemAdminClient.RequestTrialLicense(context.Background(), 1)
 		CheckErrorID(t, err, "api.license.upgrade_needed.app_error")
 		CheckForbiddenStatus(t, resp)
@@ -588,7 +519,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 		require.NoError(t, initialErr)
 
 		// Add 50 active users (50/1000 * 1000 = 50)
-		for i := 0; i < 49; i++ { // 49 + 1 basic user = 50 active users
+		for range 49 { // 49 + 1 basic user = 50 active users
 			user := th.CreateUser()
 
 			// Make user active
@@ -631,7 +562,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 		require.NoError(t, initialErr)
 
 		// Add 19 active users (19/20 * 1000 = 950)
-		for i := 0; i < 18; i++ { // 18 + 1 basic user = 19 active users
+		for range 18 { // 18 + 1 basic user = 19 active users
 			user := th.CreateUser()
 
 			// Make user active
@@ -674,7 +605,7 @@ func TestGetLicenseLoadMetric(t *testing.T) {
 		require.NoError(t, initialErr)
 
 		// Add 30 active users (30/20 * 1000 = 1500)
-		for i := 0; i < 29; i++ { // 29 + 1 basic user = 30 active users
+		for range 29 { // 29 + 1 basic user = 30 active users
 			user := th.CreateUser()
 
 			// Make user active
