@@ -13,14 +13,7 @@ import (
 	"github.com/mattermost/mattermost/server/v8/channels/testlib"
 )
 
-var replicaFlag bool
-
 func TestMain(m *testing.M) {
-	if f := flag.Lookup("mysql-replica"); f == nil {
-		flag.BoolVar(&replicaFlag, "mysql-replica", false, "")
-		flag.Parse()
-	}
-
 	var parallelism int
 	if f := flag.Lookup("test.parallel"); f != nil {
 		parallelism, _ = strconv.Atoi(f.Value.String())
@@ -33,7 +26,6 @@ func TestMain(m *testing.M) {
 	options := testlib.HelperOptions{
 		EnableStore:     true,
 		EnableResources: true,
-		WithReadReplica: replicaFlag,
 		RunParallel:     runParallel,
 		Parallelism:     parallelism,
 	}
