@@ -12,6 +12,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/dgryski/dgoogauth"
 	"github.com/gorilla/websocket"
 	"github.com/stretchr/testify/require"
 
@@ -107,7 +108,7 @@ func TestCreateDirectChannelWithSocket(t *testing.T) {
 	users := make([]*model.User, 0)
 	users = append(users, user2)
 
-	for i := 0; i < 10; i++ {
+	for range 10 {
 		users = append(users, th.CreateUser())
 	}
 
@@ -225,7 +226,7 @@ func TestWebSocketReconnectRace(t *testing.T) {
 
 	WebSocketClient.Close()
 
-	for i := 0; i < n; i++ {
+	for range n {
 		go func() {
 			defer wg.Done()
 			ws, err := th.CreateReliableWebSocketClient(connID, seq+1)
@@ -536,3 +537,147 @@ func TestValidateDisconnectErrCode(t *testing.T) {
 		})
 	}
 }
+
+// Helper function to enable MFA enforcement in config
+func enableMFAEnforcement(th *TestHelper) {
+	th.App.UpdateConfig(func(cfg *model.Config) {
+		*cfg.ServiceSettings.EnableMultifactorAuthentication = true
+		*cfg.ServiceSettings.EnforceMultifactorAuthentication = true
+	})
+}
+
+// Helper function to set up MFA for a user
+func setupUserWithMFA(t *testing.T, th *TestHelper, user *model.User) string {
+	// Setup MFA properly - following authentication_test.go pattern
+	secret, appErr := th.App.GenerateMfaSecret(user.Id)
+	require.Nil(t, appErr)
+	err := th.Server.Store().User().UpdateMfaActive(user.Id, true)
+	require.NoError(t, err)
+	err = th.Server.Store().User().UpdateMfaSecret(user.Id, secret.Secret)
+	require.NoError(t, err)
+	return secret.Secret
+}
+
+func TestWebSocketMFAEnforcement(t *testing.T) {
+	mainHelper.Parallel(t)
+
+	t.Run("WebSocket works when MFA enforcement is disabled", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+		defer th.TearDown()
+
+		// MFA enforcement disabled - should work normally
+		webSocketClient := th.CreateConnectedWebSocketClient(t)
+		defer webSocketClient.Close()
+
+		webSocketClient.GetStatuses()
+
+		select {
+		case resp := <-webSocketClient.ResponseChannel:
+			require.Nil(t, resp.Error, "WebSocket should work when MFA enforcement is disabled")
+			require.Equal(t, resp.Status, model.StatusOk)
+		case <-time.After(3 * time.Second):
+			require.Fail(t, "Expected WebSocket response but got timeout")
+		}
+	})
+
+	t.Run("WebSocket blocked when MFA required but user has no MFA", func(t *testing.T) {
+		th := SetupEnterprise(t).InitBasic()
+		defer th.TearDown()
+
+		// Enable MFA enforcement in config
+		enableMFAEnforcement(th)
+		// Defer the teardown to reset the config after the test
+		defer func() {
+			th.App.UpdateConfig(func(cfg *model.Config) {
+				*cfg.ServiceSettings.EnforceMultifactorAuthentication = false
+			})
+		}()
+
+		// Create user without MFA using existing basic user to avoid license timing issues
+		user := th.BasicUser
+
+		// Login user (this should work for initial authentication)
+		client := th.CreateClient()
+		_, _, err := client.Login(context.Background(), user.Email, "Pa$$word11")
+		require.NoError(t, err)
+
+		// Create WebSocket client - initial connection succeeds, but subsequent API requests require completed MFA
+		webSocketClient, err := th.CreateWebSocketClientWithClient(client)
+		require.NoError(t, err)
+		require.NotNil(t, webSocketClient, "webSocketClient should not be nil")
+		webSocketClient.Listen()
+		defer webSocketClient.Close()
+
+		// First, consume the successful authentication challenge response
+		authResp := <-webSocketClient.ResponseChannel
+		require.Nil(t, authResp.Error, "Authentication challenge should succeed")
+		require.Equal(t, authResp.Status, model.StatusOk)
+
+		// Individual WebSocket requests should be blocked due to MFA requirement
+		webSocketClient.GetStatuses()
+
+		// Should get authentication error due to MFA requirement on the second request
+		select {
+		case resp := <-webSocketClient.ResponseChannel:
+			t.Logf("Received response: Error=%v, Status=%s, SeqReply=%d", resp.Error, resp.Status, resp.SeqReply)
+			require.NotNil(t, resp.Error, "Should get authentication error due to MFA requirement")
+			require.Equal(t, "api.web_socket_router.not_authenticated.app_error", resp.Error.Id,
+				"Should get specific 'not authenticated' error ID due to MFA requirement")
+		case <-time.After(3 * time.Second):
+			require.Fail(t, "Expected WebSocket error response but got timeout")
+		}
+	})
+
+	t.Run("WebSocket connection allowed when user has MFA active", func(t *testing.T) {
+		th := SetupEnterprise(t).InitBasic()
+		defer th.TearDown()
+
+		// Enable MFA enforcement in config
+		enableMFAEnforcement(th)
+		// Defer the teardown to reset the config after the test
+		defer func() {
+			th.App.UpdateConfig(func(cfg *model.Config) {
+				*cfg.ServiceSettings.EnforceMultifactorAuthentication = false
+			})
+		}()
+
+		// Create user and set up MFA
+		user := &model.User{
+			Email:    th.GenerateTestEmail(),
+			Username: model.NewUsername(),
+			Password: "password123",
+		}
+		ruser, _, err := th.Client.CreateUser(context.Background(), user)
+		require.NoError(t, err)
+
+		th.LinkUserToTeam(ruser, th.BasicTeam)
+		_, err = th.App.Srv().Store().User().VerifyEmail(ruser.Id, ruser.Email)
+		require.NoError(t, err)
+
+		// Setup MFA for the user and get the secret
+		secretString := setupUserWithMFA(t, th, ruser)
+
+		// Generate TOTP token from the user's MFA secret
+		code := dgoogauth.ComputeCode(secretString, time.Now().UTC().Unix()/30)
+		token := fmt.Sprintf("%06d", code)
+
+		client := th.CreateClient()
+		_, _, err = client.LoginWithMFA(context.Background(), user.Email, user.Password, token)
+		require.NoError(t, err)
+
+		// WebSocket connection should work
+		webSocketClient := th.CreateConnectedWebSocketClientWithClient(t, client)
+		defer webSocketClient.Close()
+
+		// Should be able to get statuses
+		webSocketClient.GetStatuses()
+
+		select {
+		case resp := <-webSocketClient.ResponseChannel:
+			require.Nil(t, resp.Error, "WebSocket should work when MFA is properly set up")
+			require.Equal(t, resp.Status, model.StatusOk)
+		case <-time.After(5 * time.Second):
+			require.Fail(t, "Expected WebSocket response but got timeout")
+		}
+	})
+}
