@@ -94,7 +94,7 @@ func TestCreateBot(t *testing.T) {
 		// Check that a post was created to add bot to team and channels
 		channel, err := th.App.getOrCreateDirectChannelWithUser(th.Context, user, th.BasicUser)
 		require.Nil(t, err)
-		posts, err := th.App.GetPosts(channel.Id, 0, 1)
+		posts, err := th.App.GetPosts(th.Context, channel.Id, 0, 1)
 		require.Nil(t, err)
 
 		postArray := posts.ToSlice()
@@ -671,7 +671,7 @@ func TestDisableUserBots(t *testing.T) {
 		}
 	}()
 
-	for i := 0; i < 46; i++ {
+	for i := range 46 {
 		bot, err := th.App.CreateBot(th.Context, &model.Bot{
 			Username:    fmt.Sprintf("username%v", i),
 			Description: "a bot",
@@ -777,7 +777,7 @@ func TestNotifySysadminsBotOwnerDisabled(t *testing.T) {
 
 	// create bots owned by user (equal to numBotsToPrint)
 	var bot *model.Bot
-	for i := 0; i < numBotsToPrint; i++ {
+	for i := range numBotsToPrint {
 		bot, err = th.App.CreateBot(th.Context, &model.Bot{
 			Username:    fmt.Sprintf("bot%v", i),
 			Description: "a bot",
@@ -799,11 +799,11 @@ func TestNotifySysadminsBotOwnerDisabled(t *testing.T) {
 	require.Nil(t, err)
 
 	// get posts from sysadmin1 and sysadmin2 DM channels
-	posts1, err := th.App.GetPosts(channelSys1.Id, 0, 5)
+	posts1, err := th.App.GetPosts(th.Context, channelSys1.Id, 0, 5)
 	require.Nil(t, err)
 	assert.Empty(t, posts1.Order)
 
-	posts2, err := th.App.GetPosts(channelSys2.Id, 0, 5)
+	posts2, err := th.App.GetPosts(th.Context, channelSys2.Id, 0, 5)
 	require.Nil(t, err)
 	assert.Empty(t, posts2.Order)
 
@@ -812,11 +812,11 @@ func TestNotifySysadminsBotOwnerDisabled(t *testing.T) {
 	require.Nil(t, err)
 
 	// get posts from sysadmin1  and sysadmin2 DM channels
-	posts1, err = th.App.GetPosts(channelSys1.Id, 0, 5)
+	posts1, err = th.App.GetPosts(th.Context, channelSys1.Id, 0, 5)
 	require.Nil(t, err)
 	assert.Len(t, posts1.Order, 1)
 
-	posts2, err = th.App.GetPosts(channelSys2.Id, 0, 5)
+	posts2, err = th.App.GetPosts(th.Context, channelSys2.Id, 0, 5)
 	require.Nil(t, err)
 	assert.Len(t, posts2.Order, 1)
 
@@ -1001,3 +1001,147 @@ func TestGetSystemBot(t *testing.T) {
 		require.Equal(t, bot.UserId, botUser.Id)
 	})
 }
+
+func TestIsBotOwnedByCurrentUserOrPlugin(t *testing.T) {
+	mainHelper.Parallel(t)
+	t.Run("bot owned by current user", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+
+		bot, err := th.App.CreateBot(th.Context, &model.Bot{
+			Username:    "username",
+			Description: "a bot",
+			OwnerId:     th.BasicUser.Id,
+		})
+		require.Nil(t, err)
+		defer func() {
+			err = th.App.PermanentDeleteBot(th.Context, bot.UserId)
+			require.Nil(t, err)
+		}()
+
+		session, err := th.App.CreateSession(th.Context, &model.Session{
+			UserId: th.BasicUser.Id,
+			Roles:  th.BasicUser.GetRawRoles(),
+		})
+		require.Nil(t, err)
+
+		rctx := th.Context.WithSession(session)
+		owned, appErr := th.App.IsBotOwnedByCurrentUserOrPlugin(rctx, bot.UserId)
+		require.Nil(t, appErr)
+		assert.True(t, owned)
+	})
+
+	t.Run("bot owned by different user", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+
+		bot, err := th.App.CreateBot(th.Context, &model.Bot{
+			Username:    "username",
+			Description: "a bot",
+			OwnerId:     th.BasicUser2.Id,
+		})
+		require.Nil(t, err)
+		defer func() {
+			err = th.App.PermanentDeleteBot(th.Context, bot.UserId)
+			require.Nil(t, err)
+		}()
+
+		session, err := th.App.CreateSession(th.Context, &model.Session{
+			UserId: th.BasicUser.Id,
+			Roles:  th.BasicUser.GetRawRoles(),
+		})
+		require.Nil(t, err)
+
+		rctx := th.Context.WithSession(session)
+		owned, appErr := th.App.IsBotOwnedByCurrentUserOrPlugin(rctx, bot.UserId)
+		require.Nil(t, appErr)
+		assert.False(t, owned)
+	})
+
+	t.Run("invalid bot ID", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+
+		session, err := th.App.CreateSession(th.Context, &model.Session{
+			UserId: th.BasicUser.Id,
+			Roles:  th.BasicUser.GetRawRoles(),
+		})
+		require.Nil(t, err)
+
+		rctx := th.Context.WithSession(session)
+		owned, appErr := th.App.IsBotOwnedByCurrentUserOrPlugin(rctx, model.NewId())
+		require.NotNil(t, appErr)
+		assert.False(t, owned)
+		require.Equal(t, "store.sql_bot.get.missing.app_error", appErr.Id)
+	})
+
+	t.Run("bot owned by plugin when no plugins environment", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+
+		pluginID := "test-plugin-id"
+		bot, err := th.App.CreateBot(th.Context, &model.Bot{
+			Username:    "username",
+			Description: "a bot",
+			OwnerId:     pluginID,
+		})
+		require.Nil(t, err)
+		defer func() {
+			err = th.App.PermanentDeleteBot(th.Context, bot.UserId)
+			require.Nil(t, err)
+		}()
+
+		session, err := th.App.CreateSession(th.Context, &model.Session{
+			UserId: th.BasicUser.Id,
+			Roles:  th.BasicUser.GetRawRoles(),
+		})
+		require.Nil(t, err)
+
+		rctx := th.Context.WithSession(session)
+		owned, appErr := th.App.IsBotOwnedByCurrentUserOrPlugin(rctx, bot.UserId)
+		require.Nil(t, appErr)
+		assert.False(t, owned)
+	})
+
+	t.Run("bot owned by plugin", func(t *testing.T) {
+		th := Setup(t).InitBasic()
+
+		pluginID := "com.mattermost.testplugin"
+		pluginCode := `
+		package main
+
+		import (
+			"github.com/mattermost/mattermost/server/public/plugin"
+		)
+
+		type MyPlugin struct {
+			plugin.MattermostPlugin
+		}
+
+		func main() {
+			plugin.ClientMain(&MyPlugin{})
+		}
+	`
+		pluginManifest := `{"id": "com.mattermost.testplugin", "server": {"executable": "backend.exe"}}`
+
+		setupPluginAPITest(t, pluginCode, pluginManifest, pluginID, th.App, th.Context)
+
+		bot, err := th.App.CreateBot(th.Context, &model.Bot{
+			Username:    "username",
+			Description: "a bot",
+			OwnerId:     pluginID,
+		})
+		require.Nil(t, err)
+		defer func() {
+			err = th.App.PermanentDeleteBot(th.Context, bot.UserId)
+			require.Nil(t, err)
+		}()
+
+		session, err := th.App.CreateSession(th.Context, &model.Session{
+			UserId: th.BasicUser.Id,
+			Roles:  th.BasicUser.GetRawRoles(),
+		})
+		require.Nil(t, err)
+
+		rctx := th.Context.WithSession(session)
+		owned, appErr := th.App.IsBotOwnedByCurrentUserOrPlugin(rctx, bot.UserId)
+		require.Nil(t, appErr)
+		assert.True(t, owned)
+	})
+}
