@@ -110,14 +110,14 @@ var exportablePreferences = map[imports.ComparablePreference]string{
 	}: "EmailInterval",
 }
 
-func (a *App) BulkExport(ctx request.CTX, writer io.Writer, outPath string, job *model.Job, opts model.BulkExportOpts) *model.AppError {
+func (a *App) BulkExport(rctx request.CTX, writer io.Writer, outPath string, job *model.Job, opts model.BulkExportOpts) *model.AppError {
 	var zipWr *zip.Writer
 	if opts.CreateArchive {
 		var err error
 		zipWr = zip.NewWriter(writer)
 		defer func() {
 			if err = zipWr.Close(); err != nil {
-				ctx.Logger().Error("Error closing zip writer", mlog.Err(err))
+				rctx.Logger().Error("Error closing zip writer", mlog.Err(err))
 			}
 		}()
 		writer, err = zipWr.Create("import.jsonl")
@@ -135,73 +135,73 @@ func (a *App) BulkExport(ctx request.CTX, writer io.Writer, outPath string, job
 		job.Data = make(model.StringMap)
 	}
 
-	ctx.Logger().Info("Bulk export: exporting version")
+	rctx.Logger().Info("Bulk export: exporting version")
 	if err := a.exportVersion(writer); err != nil {
 		return err
 	}
 
 	if opts.IncludeRolesAndSchemes {
-		if err := a.exportRolesAndSchemes(ctx, job, writer); err != nil {
+		if err := a.exportRolesAndSchemes(rctx, job, writer); err != nil {
 			return err
 		}
 	}
 
-	ctx.Logger().Info("Bulk export: exporting teams")
-	teamNames, appErr := a.exportAllTeams(ctx, job, writer)
+	rctx.Logger().Info("Bulk export: exporting teams")
+	teamNames, appErr := a.exportAllTeams(rctx, job, writer)
 	if appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting channels")
-	if appErr = a.exportAllChannels(ctx, job, writer, teamNames, opts.IncludeArchivedChannels); appErr != nil {
+	rctx.Logger().Info("Bulk export: exporting channels")
+	if appErr = a.exportAllChannels(rctx, job, writer, teamNames, opts.IncludeArchivedChannels); appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting users")
-	profilePictures, appErr := a.exportAllUsers(ctx, job, writer, opts.IncludeArchivedChannels, opts.IncludeProfilePictures)
+	rctx.Logger().Info("Bulk export: exporting users")
+	profilePictures, appErr := a.exportAllUsers(rctx, job, writer, opts.IncludeArchivedChannels, opts.IncludeProfilePictures)
 	if appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting bots")
-	botPPs, appErr := a.exportAllBots(ctx, job, writer, opts.IncludeProfilePictures)
+	rctx.Logger().Info("Bulk export: exporting bots")
+	botPPs, appErr := a.exportAllBots(rctx, job, writer, opts.IncludeProfilePictures)
 	if appErr != nil {
 		return appErr
 	}
 	profilePictures = append(profilePictures, botPPs...)
 
-	ctx.Logger().Info("Bulk export: exporting posts")
-	attachments, appErr := a.exportAllPosts(ctx, job, writer, opts.IncludeAttachments, opts.IncludeArchivedChannels)
+	rctx.Logger().Info("Bulk export: exporting posts")
+	attachments, appErr := a.exportAllPosts(rctx, job, writer, opts.IncludeAttachments, opts.IncludeArchivedChannels)
 	if appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting emoji")
-	emojiPaths, appErr := a.exportCustomEmoji(ctx, job, writer, outPath, "exported_emoji", !opts.CreateArchive)
+	rctx.Logger().Info("Bulk export: exporting emoji")
+	emojiPaths, appErr := a.exportCustomEmoji(rctx, job, writer, outPath, "exported_emoji", !opts.CreateArchive)
 	if appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting direct channels")
-	if appErr = a.exportAllDirectChannels(ctx, job, writer, opts.IncludeArchivedChannels); appErr != nil {
+	rctx.Logger().Info("Bulk export: exporting direct channels")
+	if appErr = a.exportAllDirectChannels(rctx, job, writer, opts.IncludeArchivedChannels); appErr != nil {
 		return appErr
 	}
 
-	ctx.Logger().Info("Bulk export: exporting direct posts")
-	directAttachments, appErr := a.exportAllDirectPosts(ctx, job, writer, opts.IncludeAttachments, opts.IncludeArchivedChannels)
+	rctx.Logger().Info("Bulk export: exporting direct posts")
+	directAttachments, appErr := a.exportAllDirectPosts(rctx, job, writer, opts.IncludeAttachments, opts.IncludeArchivedChannels)
 	if appErr != nil {
 		return appErr
 	}
 
 	if opts.IncludeAttachments {
-		ctx.Logger().Info("Bulk export: exporting file attachments")
-		warnings, appErr := a.exportAttachments(ctx, attachments, outPath, zipWr)
+		rctx.Logger().Info("Bulk export: exporting file attachments")
+		warnings, appErr := a.exportAttachments(rctx, attachments, outPath, zipWr)
 		if appErr != nil {
 			return appErr
 		}
 
-		ctx.Logger().Info("Bulk export: exporting direct file attachments")
-		newWarnings, appErr := a.exportAttachments(ctx, directAttachments, outPath, zipWr)
+		rctx.Logger().Info("Bulk export: exporting direct file attachments")
+		newWarnings, appErr := a.exportAttachments(rctx, directAttachments, outPath, zipWr)
 		if appErr != nil {
 			return appErr
 		}
@@ -209,15 +209,15 @@ func (a *App) BulkExport(ctx request.CTX, writer io.Writer, outPath string, job
 
 		totalExportedEmojis := 0
 		emojisLen := len(emojiPaths)
-		ctx.Logger().Info("Bulk export: exporting custom emojis")
+		rctx.Logger().Info("Bulk export: exporting custom emojis")
 		for _, emojiPath := range emojiPaths {
-			if err := a.exportFile(ctx, outPath, emojiPath, zipWr); err != nil {
-				ctx.Logger().Warn("Unable to export emoji", mlog.String("emoji_path", emojiPath), mlog.Err(err))
+			if err := a.exportFile(rctx, outPath, emojiPath, zipWr); err != nil {
+				rctx.Logger().Warn("Unable to export emoji", mlog.String("emoji_path", emojiPath), mlog.Err(err))
 			} else {
 				totalExportedEmojis++
 			}
 			if totalExportedEmojis%10 == 0 {
-				ctx.Logger().Info("Bulk export: exporting emojis progress", mlog.Int("total_successfully_exported_emojis", totalExportedEmojis), mlog.Int("total_emojis_to_export", emojisLen))
+				rctx.Logger().Info("Bulk export: exporting emojis progress", mlog.Int("total_successfully_exported_emojis", totalExportedEmojis), mlog.Int("total_emojis_to_export", emojisLen))
 			}
 		}
 
@@ -230,39 +230,39 @@ func (a *App) BulkExport(ctx request.CTX, writer io.Writer, outPath string, job
 						nil, "", http.StatusInternalServerError).Wrap(err)
 				}
 			}
-			updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "num_warnings", len(warnings))
+			updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "num_warnings", len(warnings))
 		}
 
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "attachments_exported", len(attachments)+len(directAttachments)+len(emojiPaths))
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "attachments_exported", len(attachments)+len(directAttachments)+len(emojiPaths))
 	}
 
 	if opts.IncludeProfilePictures {
-		ctx.Logger().Info("Bulk export: exporting profile pictures")
+		rctx.Logger().Info("Bulk export: exporting profile pictures")
 		for _, profilePicture := range profilePictures {
-			if err := a.exportFile(ctx, outPath, profilePicture, zipWr); err != nil {
-				ctx.Logger().Warn("Unable to export profile picture", mlog.String("profile_picture", profilePicture), mlog.Err(err))
+			if err := a.exportFile(rctx, outPath, profilePicture, zipWr); err != nil {
+				rctx.Logger().Warn("Unable to export profile picture", mlog.String("profile_picture", profilePicture), mlog.Err(err))
 			}
 		}
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "profile_pictures_exported", len(profilePictures))
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "profile_pictures_exported", len(profilePictures))
 	}
 
 	return nil
 }
 
-func (a *App) exportAttachments(ctx request.CTX, attachments []imports.AttachmentImportData, outPath string,
+func (a *App) exportAttachments(rctx request.CTX, attachments []imports.AttachmentImportData, outPath string,
 	zipWr *zip.Writer) ([]string, *model.AppError) {
 	totalExportedFiles := 0
 	attachmentsLen := len(attachments)
 	var warnings []string
 	for _, attachment := range attachments {
-		if err := a.exportFile(ctx, outPath, *attachment.Path, zipWr); err != nil {
-			ctx.Logger().Warn("Unable to export file attachment", mlog.String("attachment_path", *attachment.Path), mlog.Err(err))
+		if err := a.exportFile(rctx, outPath, *attachment.Path, zipWr); err != nil {
+			rctx.Logger().Warn("Unable to export file attachment", mlog.String("attachment_path", *attachment.Path), mlog.Err(err))
 			warnings = append(warnings, fmt.Sprintf("Unable to export file attachment, attachment path: %s , error: %s", *attachment.Path, err.Error()))
 		} else {
 			totalExportedFiles++
 		}
 		if totalExportedFiles%10 == 0 {
-			ctx.Logger().Info("Bulk export: exporting file attachments progress", mlog.Int("total_successfully_exported_files", totalExportedFiles), mlog.Int("total_files_to_export", attachmentsLen))
+			rctx.Logger().Info("Bulk export: exporting file attachments progress", mlog.Int("total_successfully_exported_files", totalExportedFiles), mlog.Int("total_files_to_export", attachmentsLen))
 		}
 	}
 	return warnings, nil
@@ -299,7 +299,7 @@ func (a *App) exportVersion(writer io.Writer) *model.AppError {
 	return a.exportWriteLine(writer, versionLine)
 }
 
-func (a *App) exportRolesAndSchemes(ctx request.CTX, job *model.Job, writer io.Writer) *model.AppError {
+func (a *App) exportRolesAndSchemes(rctx request.CTX, job *model.Job, writer io.Writer) *model.AppError {
 	// We export schemes first since they'll already include their attached roles
 	// which we map to avoid exporting them twice later in exportRoles.
 	schemeRolesMap := make(map[string]bool)
@@ -309,25 +309,25 @@ func (a *App) exportRolesAndSchemes(ctx request.CTX, job *model.Job, writer io.W
 		return model.NewAppError("exportRolesAndSchemes", "app.role.get_all.app_error", nil, "", http.StatusInternalServerError).Wrap(appErr)
 	}
 
-	ctx.Logger().Info("Bulk export: exporting team schemes")
-	if err := a.exportSchemes(ctx, job, writer, model.SchemeScopeTeam, schemeRolesMap, roles); err != nil {
+	rctx.Logger().Info("Bulk export: exporting team schemes")
+	if err := a.exportSchemes(rctx, job, writer, model.SchemeScopeTeam, schemeRolesMap, roles); err != nil {
 		return err
 	}
 
-	ctx.Logger().Info("Bulk export: exporting channel schemes")
-	if err := a.exportSchemes(ctx, job, writer, model.SchemeScopeChannel, schemeRolesMap, roles); err != nil {
+	rctx.Logger().Info("Bulk export: exporting channel schemes")
+	if err := a.exportSchemes(rctx, job, writer, model.SchemeScopeChannel, schemeRolesMap, roles); err != nil {
 		return err
 	}
 
-	ctx.Logger().Info("Bulk export: exporting roles")
-	if err := a.exportRoles(ctx, job, writer, schemeRolesMap, roles); err != nil {
+	rctx.Logger().Info("Bulk export: exporting roles")
+	if err := a.exportRoles(rctx, job, writer, schemeRolesMap, roles); err != nil {
 		return err
 	}
 
 	return nil
 }
 
-func (a *App) exportRoles(ctx request.CTX, job *model.Job, writer io.Writer, schemeRoles map[string]bool, allRoles []*model.Role) *model.AppError {
+func (a *App) exportRoles(rctx request.CTX, job *model.Job, writer io.Writer, schemeRoles map[string]bool, allRoles []*model.Role) *model.AppError {
 	var cnt int
 	for _, role := range allRoles {
 		// We skip any roles that will be included as part of custom schemes.
@@ -339,12 +339,12 @@ func (a *App) exportRoles(ctx request.CTX, job *model.Job, writer io.Writer, sch
 		}
 	}
 
-	updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "roles_exported", cnt)
+	updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "roles_exported", cnt)
 
 	return nil
 }
 
-func (a *App) exportSchemes(ctx request.CTX, job *model.Job, writer io.Writer, scope string, schemeRolesMap map[string]bool, allRoles []*model.Role) *model.AppError {
+func (a *App) exportSchemes(rctx request.CTX, job *model.Job, writer io.Writer, scope string, schemeRolesMap map[string]bool, allRoles []*model.Role) *model.AppError {
 	rolesMap := make(map[string]*model.Role, len(allRoles))
 	for _, role := range allRoles {
 		rolesMap[role.Name] = role
@@ -391,7 +391,7 @@ func (a *App) exportSchemes(ctx request.CTX, job *model.Job, writer io.Writer, s
 
 		cnt += len(schemes)
 
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, fmt.Sprintf("%s_schemes_exported", scope), cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, fmt.Sprintf("%s_schemes_exported", scope), cnt)
 
 		if len(schemes) < pageSize {
 			return nil
@@ -399,7 +399,7 @@ func (a *App) exportSchemes(ctx request.CTX, job *model.Job, writer io.Writer, s
 	}
 }
 
-func (a *App) exportAllTeams(ctx request.CTX, job *model.Job, writer io.Writer) (map[string]bool, *model.AppError) {
+func (a *App) exportAllTeams(rctx request.CTX, job *model.Job, writer io.Writer) (map[string]bool, *model.AppError) {
 	afterId := strings.Repeat("0", 26)
 	teamNames := make(map[string]bool)
 	cnt := 0
@@ -413,7 +413,7 @@ func (a *App) exportAllTeams(ctx request.CTX, job *model.Job, writer io.Writer)
 			break
 		}
 		cnt += len(teams)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "teams_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "teams_exported", cnt)
 
 		for _, team := range teams {
 			afterId = team.Id
@@ -434,7 +434,7 @@ func (a *App) exportAllTeams(ctx request.CTX, job *model.Job, writer io.Writer)
 	return teamNames, nil
 }
 
-func (a *App) exportAllChannels(ctx request.CTX, job *model.Job, writer io.Writer, teamNames map[string]bool, withArchived bool) *model.AppError {
+func (a *App) exportAllChannels(rctx request.CTX, job *model.Job, writer io.Writer, teamNames map[string]bool, withArchived bool) *model.AppError {
 	afterId := strings.Repeat("0", 26)
 	cnt := 0
 	for {
@@ -447,7 +447,7 @@ func (a *App) exportAllChannels(ctx request.CTX, job *model.Job, writer io.Write
 			break
 		}
 		cnt += len(channels)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "channels_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "channels_exported", cnt)
 
 		for _, channel := range channels {
 			afterId = channel.Id
@@ -471,7 +471,7 @@ func (a *App) exportAllChannels(ctx request.CTX, job *model.Job, writer io.Write
 	return nil
 }
 
-func (a *App) exportAllUsers(ctx request.CTX, job *model.Job, writer io.Writer, includeArchivedChannels, includeProfilePictures bool) ([]string, *model.AppError) {
+func (a *App) exportAllUsers(rctx request.CTX, job *model.Job, writer io.Writer, includeArchivedChannels, includeProfilePictures bool) ([]string, *model.AppError) {
 	afterId := strings.Repeat("0", 26)
 	cnt := 0
 	profilePictures := []string{}
@@ -485,7 +485,7 @@ func (a *App) exportAllUsers(ctx request.CTX, job *model.Job, writer io.Writer,
 			break
 		}
 		cnt += len(users)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "users_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "users_exported", cnt)
 
 		for _, user := range users {
 			afterId = user.Id
@@ -497,7 +497,7 @@ func (a *App) exportAllUsers(ctx request.CTX, job *model.Job, writer io.Writer,
 
 			// Gathering here the exportable preferences to pass them on to importLineFromUser
 			exportedPrefs := make(map[string]*string)
-			allPrefs, err := a.GetPreferencesForUser(ctx, user.Id)
+			allPrefs, err := a.GetPreferencesForUser(rctx, user.Id)
 			if err != nil {
 				return profilePictures, err
 			}
@@ -555,7 +555,7 @@ func (a *App) exportAllUsers(ctx request.CTX, job *model.Job, writer io.Writer,
 			}
 
 			// Do the Team Memberships.
-			members, err := a.buildUserTeamAndChannelMemberships(ctx, user.Id, includeArchivedChannels)
+			members, err := a.buildUserTeamAndChannelMemberships(rctx, user.Id, includeArchivedChannels)
 			if err != nil {
 				return profilePictures, err
 			}
@@ -571,7 +571,7 @@ func (a *App) exportAllUsers(ctx request.CTX, job *model.Job, writer io.Writer,
 	return profilePictures, nil
 }
 
-func (a *App) exportAllBots(ctx request.CTX, job *model.Job, writer io.Writer, includeProfilePictures bool) ([]string, *model.AppError) {
+func (a *App) exportAllBots(rctx request.CTX, job *model.Job, writer io.Writer, includeProfilePictures bool) ([]string, *model.AppError) {
 	afterId := ""
 	cnt := 0
 	profilePictures := []string{}
@@ -585,13 +585,13 @@ func (a *App) exportAllBots(ctx request.CTX, job *model.Job, writer io.Writer, i
 		}
 
 		cnt += len(bots)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "bots_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "bots_exported", cnt)
 
 		for _, bot := range bots {
 			afterId = bot.UserId
 
 			var ownerUsername string
-			owner, err := a.Srv().Store().User().Get(ctx.Context(), bot.OwnerId)
+			owner, err := a.Srv().Store().User().Get(rctx.Context(), bot.OwnerId)
 			if err != nil {
 				var nfErr *store.ErrNotFound
 				if errors.As(err, &nfErr) {
@@ -629,7 +629,7 @@ func (a *App) exportAllBots(ctx request.CTX, job *model.Job, writer io.Writer, i
 	return profilePictures, nil
 }
 
-func (a *App) buildUserTeamAndChannelMemberships(c request.CTX, userID string, includeArchivedChannels bool) (*[]imports.UserTeamImportData, *model.AppError) {
+func (a *App) buildUserTeamAndChannelMemberships(rctx request.CTX, userID string, includeArchivedChannels bool) (*[]imports.UserTeamImportData, *model.AppError) {
 	var memberships []imports.UserTeamImportData
 
 	members, err := a.Srv().Store().Team().GetTeamMembersForExport(userID)
@@ -646,7 +646,7 @@ func (a *App) buildUserTeamAndChannelMemberships(c request.CTX, userID string, i
 		memberData := importUserTeamDataFromTeamMember(member)
 
 		// Do the Channel Memberships.
-		channelMembers, err := a.buildUserChannelMemberships(c, userID, member.TeamId, includeArchivedChannels)
+		channelMembers, err := a.buildUserChannelMemberships(rctx, userID, member.TeamId, includeArchivedChannels)
 		if err != nil {
 			return nil, err
 		}
@@ -665,14 +665,14 @@ func (a *App) buildUserTeamAndChannelMemberships(c request.CTX, userID string, i
 	return &memberships, nil
 }
 
-func (a *App) buildUserChannelMemberships(c request.CTX, userID string, teamID string, includeArchivedChannels bool) (*[]imports.UserChannelImportData, *model.AppError) {
+func (a *App) buildUserChannelMemberships(rctx request.CTX, userID string, teamID string, includeArchivedChannels bool) (*[]imports.UserChannelImportData, *model.AppError) {
 	members, nErr := a.Srv().Store().Channel().GetChannelMembersForExport(userID, teamID, includeArchivedChannels)
 	if nErr != nil {
 		return nil, model.NewAppError("buildUserChannelMemberships", "app.channel.get_members.app_error", nil, "", http.StatusInternalServerError).Wrap(nErr)
 	}
 
 	category := model.PreferenceCategoryFavoriteChannel
-	preferences, err := a.GetPreferenceByCategoryForUser(c, userID, category)
+	preferences, err := a.GetPreferenceByCategoryForUser(rctx, userID, category)
 	if err != nil && err.StatusCode != http.StatusNotFound {
 		return nil, err
 	}
@@ -704,7 +704,7 @@ func (a *App) buildUserNotifyProps(notifyProps model.StringMap) *imports.UserNot
 	}
 }
 
-func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer, withAttachments bool, includeArchivedChannels bool) ([]imports.AttachmentImportData, *model.AppError) {
+func (a *App) exportAllPosts(rctx request.CTX, job *model.Job, writer io.Writer, withAttachments bool, includeArchivedChannels bool) ([]imports.AttachmentImportData, *model.AppError) {
 	var attachments []imports.AttachmentImportData
 	afterId := strings.Repeat("0", 26)
 	var postProcessCount uint64
@@ -713,7 +713,7 @@ func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer,
 	cnt := 0
 	for {
 		if time.Since(logCheckpoint) > 5*time.Minute {
-			ctx.Logger().Debug(fmt.Sprintf("Bulk Export: processed %d posts", postProcessCount))
+			rctx.Logger().Debug(fmt.Sprintf("Bulk Export: processed %d posts", postProcessCount))
 			logCheckpoint = time.Now()
 		}
 
@@ -726,7 +726,7 @@ func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer,
 			return attachments, nil
 		}
 		cnt += len(posts)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "posts_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "posts_exported", cnt)
 
 		for _, post := range posts {
 			afterId = post.Id
@@ -739,12 +739,12 @@ func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer,
 
 			postLine := importLineForPost(post)
 
-			replies, replyAttachments, err := a.buildPostReplies(ctx, post.Id, withAttachments)
+			replies, replyAttachments, err := a.buildPostReplies(rctx, post.Id, withAttachments)
 			if err != nil {
 				return nil, err
 			}
 
-			followers, err := a.buildThreadFollowers(ctx, post.Id)
+			followers, err := a.buildThreadFollowers(rctx, post.Id)
 			if err != nil {
 				return nil, err
 			}
@@ -760,7 +760,7 @@ func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer,
 			postLine.Post.Replies = &replies
 			postLine.Post.Reactions = &[]imports.ReactionImportData{}
 			if post.HasReactions {
-				postLine.Post.Reactions, err = a.BuildPostReactions(ctx, post.Id)
+				postLine.Post.Reactions, err = a.BuildPostReactions(rctx, post.Id)
 				if err != nil {
 					return nil, err
 				}
@@ -785,7 +785,7 @@ func (a *App) exportAllPosts(ctx request.CTX, job *model.Job, writer io.Writer,
 	}
 }
 
-func (a *App) buildPostReplies(ctx request.CTX, postID string, withAttachments bool) ([]imports.ReplyImportData, []imports.AttachmentImportData, *model.AppError) {
+func (a *App) buildPostReplies(rctx request.CTX, postID string, withAttachments bool) ([]imports.ReplyImportData, []imports.AttachmentImportData, *model.AppError) {
 	var replies []imports.ReplyImportData
 	var attachments []imports.AttachmentImportData
 
@@ -798,7 +798,7 @@ func (a *App) buildPostReplies(ctx request.CTX, postID string, withAttachments b
 		replyImportObject := importReplyFromPost(reply)
 		if reply.HasReactions {
 			var appErr *model.AppError
-			replyImportObject.Reactions, appErr = a.BuildPostReactions(ctx, reply.Id)
+			replyImportObject.Reactions, appErr = a.BuildPostReactions(rctx, reply.Id)
 			if appErr != nil {
 				return nil, nil, appErr
 			}
@@ -835,7 +835,7 @@ func (a *App) buildThreadFollowers(_ request.CTX, postID string) ([]imports.Thre
 	return followers, nil
 }
 
-func (a *App) BuildPostReactions(ctx request.CTX, postID string) (*[]ReactionImportData, *model.AppError) {
+func (a *App) BuildPostReactions(rctx request.CTX, postID string) (*[]ReactionImportData, *model.AppError) {
 	var reactionsOfPost []imports.ReactionImportData
 
 	reactions, nErr := a.Srv().Store().Reaction().GetForPost(postID, true)
@@ -848,7 +848,7 @@ func (a *App) BuildPostReactions(ctx request.CTX, postID string) (*[]ReactionImp
 		if err != nil {
 			var nfErr *store.ErrNotFound
 			if errors.As(err, &nfErr) { // this is a valid case, the user that reacted might've been deleted by now
-				ctx.Logger().Info("Skipping reactions by user since the entity doesn't exist anymore", mlog.String("user_id", reaction.UserId))
+				rctx.Logger().Info("Skipping reactions by user since the entity doesn't exist anymore", mlog.String("user_id", reaction.UserId))
 				continue
 			}
 			return nil, model.NewAppError("BuildPostReactions", "app.user.get.app_error", nil, "", http.StatusInternalServerError).Wrap(err)
@@ -965,7 +965,7 @@ func (a *App) copyEmojiImages(rctx request.CTX, emojiId string, emojiImagePath s
 	return nil
 }
 
-func (a *App) exportAllDirectChannels(ctx request.CTX, job *model.Job, writer io.Writer, includeArchivedChannels bool) *model.AppError {
+func (a *App) exportAllDirectChannels(rctx request.CTX, job *model.Job, writer io.Writer, includeArchivedChannels bool) *model.AppError {
 	afterId := strings.Repeat("0", 26)
 	cnt := 0
 	for {
@@ -978,7 +978,7 @@ func (a *App) exportAllDirectChannels(ctx request.CTX, job *model.Job, writer io
 			break
 		}
 		cnt += len(channels)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "direct_channels_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "direct_channels_exported", cnt)
 
 		for _, channel := range channels {
 			afterId = channel.Id
@@ -1004,7 +1004,7 @@ func (a *App) exportAllDirectChannels(ctx request.CTX, job *model.Job, writer io
 					// this is the case of a group channel when other user is permanently deleted
 					// we skip this channel and inform by logging it.
 					job.Data["skipped_direct_channels"] = job.Data["skipped_direct_channels"] + "," + channel.Id
-					ctx.Logger().Warn("Skipping group channels with partially deleted members", mlog.String("channel_id", channel.Id))
+					rctx.Logger().Warn("Skipping group channels with partially deleted members", mlog.String("channel_id", channel.Id))
 					continue
 				}
 			case model.ChannelTypeDirect:
@@ -1012,7 +1012,7 @@ func (a *App) exportAllDirectChannels(ctx request.CTX, job *model.Job, writer io
 					// this is the case of a direct channel when other user is permanently deleted
 					// we skip this channel and inform by logging it.
 					job.Data["skipped_direct_channels"] = job.Data["skipped_direct_channels"] + "," + channel.Id
-					ctx.Logger().Info("Skipping direct channel with one active member", mlog.String("channel_id", channel.Id), mlog.String("user_id", channel.Members[0].UserId))
+					rctx.Logger().Info("Skipping direct channel with one active member", mlog.String("channel_id", channel.Id), mlog.String("user_id", channel.Members[0].UserId))
 					continue
 				}
 			}
@@ -1109,7 +1109,7 @@ func (a *App) buildShownByList(channel *model.DirectChannelForExport) ([]string,
 	return shownBy, nil
 }
 
-func (a *App) exportAllDirectPosts(ctx request.CTX, job *model.Job, writer io.Writer, withAttachments, includeArchivedChannels bool) ([]imports.AttachmentImportData, *model.AppError) {
+func (a *App) exportAllDirectPosts(rctx request.CTX, job *model.Job, writer io.Writer, withAttachments, includeArchivedChannels bool) ([]imports.AttachmentImportData, *model.AppError) {
 	var attachments []imports.AttachmentImportData
 	afterId := strings.Repeat("0", 26)
 	var postProcessCount uint64
@@ -1118,7 +1118,7 @@ func (a *App) exportAllDirectPosts(ctx request.CTX, job *model.Job, writer io.Wr
 	cnt := 0
 	for {
 		if time.Since(logCheckpoint) > 5*time.Minute {
-			ctx.Logger().Debug(fmt.Sprintf("Bulk Export: processed %d direct posts", postProcessCount))
+			rctx.Logger().Debug(fmt.Sprintf("Bulk Export: processed %d direct posts", postProcessCount))
 			logCheckpoint = time.Now()
 		}
 
@@ -1131,7 +1131,7 @@ func (a *App) exportAllDirectPosts(ctx request.CTX, job *model.Job, writer io.Wr
 			break
 		}
 		cnt += len(posts)
-		updateJobProgress(ctx.Logger(), a.Srv().Store(), job, "direct_posts_exported", cnt)
+		updateJobProgress(rctx.Logger(), a.Srv().Store(), job, "direct_posts_exported", cnt)
 
 		channelsToSkip := model.SliceToMapKey(strings.Split(job.Data["skipped_direct_channels"], ",")...)
 		for _, post := range posts {
@@ -1162,7 +1162,7 @@ func (a *App) exportAllDirectPosts(ctx request.CTX, job *model.Job, writer io.Wr
 			}
 
 			// Do the Replies.
-			replies, replyAttachments, err := a.buildPostReplies(ctx, post.Id, withAttachments)
+			replies, replyAttachments, err := a.buildPostReplies(rctx, post.Id, withAttachments)
 			if err != nil {
 				return nil, err
 			}
@@ -1177,7 +1177,7 @@ func (a *App) exportAllDirectPosts(ctx request.CTX, job *model.Job, writer io.Wr
 				postLine.DirectPost.Attachments = &postAttachments
 			}
 
-			followers, err := a.buildThreadFollowers(ctx, post.Id)
+			followers, err := a.buildThreadFollowers(rctx, post.Id)
 			if err != nil {
 				return nil, err
 			}
