@@ -614,17 +614,12 @@ func (a *App) getAddExperimentalSubsectionPermissions() (permissionsMap, error)
 		// Give the new subsection READ permissions to any user with READ_EXPERIMENTAL
 		permissionTransformation{
 			On:  permissionExists(model.PermissionSysconsoleReadExperimental.Id),
-			Add: []string{model.PermissionSysconsoleReadExperimentalBleve.Id, model.PermissionSysconsoleReadExperimentalFeatures.Id, model.PermissionSysconsoleReadExperimentalFeatureFlags.Id},
+			Add: []string{model.PermissionSysconsoleReadExperimentalFeatures.Id, model.PermissionSysconsoleReadExperimentalFeatureFlags.Id},
 		},
 		// Give the new subsection WRITE permissions to any user with WRITE_EXPERIMENTAL
 		permissionTransformation{
 			On:  permissionExists(model.PermissionSysconsoleWriteExperimental.Id),
-			Add: []string{model.PermissionSysconsoleWriteExperimentalBleve.Id, model.PermissionSysconsoleWriteExperimentalFeatures.Id, model.PermissionSysconsoleWriteExperimentalFeatureFlags.Id},
-		},
-		// Give the ancillary permissions MANAGE_JOBS and PURGE_BLEVE_INDEXES to anyone with WRITE_EXPERIMENTAL_BLEVE
-		permissionTransformation{
-			On:  permissionExists(model.PermissionSysconsoleWriteExperimentalBleve.Id),
-			Add: []string{model.PermissionCreatePostBleveIndexesJob.Id, model.PermissionPurgeBleveIndexes.Id},
+			Add: []string{model.PermissionSysconsoleWriteExperimentalFeatures.Id, model.PermissionSysconsoleWriteExperimentalFeatureFlags.Id},
 		},
 	}, nil
 }
@@ -1097,10 +1092,6 @@ func (a *App) getAddManageJobAncillaryPermissionsMigration() (permissionsMap, er
 			On:  permissionExists(model.PermissionSysconsoleWriteComplianceDataRetentionPolicy.Id),
 			Add: []string{model.PermissionManageDataRetentionJob.Id},
 		},
-		permissionTransformation{
-			On:  permissionExists(model.PermissionSysconsoleWriteExperimentalBleve.Id),
-			Add: []string{model.PermissionManagePostBleveIndexesJob.Id},
-		},
 		permissionTransformation{
 			On:  permissionExists(model.PermissionSysconsoleWriteComplianceComplianceExport.Id),
 			Add: []string{model.PermissionManageComplianceExportJob.Id},
@@ -1189,6 +1180,21 @@ func (a *App) getAddChannelBannerPermissionMigration() (permissionsMap, error) {
 	}, nil
 }
 
+func (a *App) getAddChannelAccessRulesPermissionMigration() (permissionsMap, error) {
+	return permissionsMap{
+		permissionTransformation{
+			On: permissionOr(
+				isRole(model.ChannelAdminRoleId),
+				isRole(model.TeamAdminRoleId),
+				isRole(model.SystemAdminRoleId),
+			),
+			Add: []string{
+				model.PermissionManageChannelAccessRules.Id,
+			},
+		},
+	}, nil
+}
+
 // Only sysadmins, team admins, and users with channels and groups managements have access to "convert channel to public"
 func (a *App) getRestrictAcessToChannelConversionToPublic() (permissionsMap, error) {
 	return []permissionTransformation{
@@ -1260,6 +1266,7 @@ func (s *Server) doPermissionsMigrations() error {
 		{Key: model.MigrationRemoveGetAnalyticsPermission, Migration: a.removeGetAnalyticsPermissionMigration},
 		{Key: model.MigrationAddSysconsoleMobileSecurityPermission, Migration: a.addSysConsoleMobileSecurityPermission},
 		{Key: model.MigrationKeyAddChannelBannerPermissions, Migration: a.getAddChannelBannerPermissionMigration},
+		{Key: model.MigrationKeyAddChannelAccessRulesPermission, Migration: a.getAddChannelAccessRulesPermissionMigration},
 	}
 
 	roles, err := s.Store().Role().GetAll()
