@@ -5,6 +5,7 @@ package app
 
 import (
 	"database/sql"
+	"errors"
 	"net/http"
 
 	"github.com/mattermost/mattermost/server/public/model"
@@ -36,3 +37,12 @@ func (a *App) GetPriorityForPostList(list *model.PostList) (map[string]*model.Po
 func (a *App) IsPostPriorityEnabled() bool {
 	return *a.Config().ServiceSettings.PostPriority
 }
+
+func (a *App) DeletePriorityForPost(postId string) *model.AppError {
+	err := a.Srv().Store().PostPriority().Delete(postId)
+	if err != nil && !errors.Is(err, sql.ErrNoRows) {
+		return model.NewAppError("DeletePriorityForPost", "app.post_priority.delete_for_post.app_error", nil, "", http.StatusInternalServerError).Wrap(err)
+	}
+
+	return nil
+}
