@@ -472,42 +472,6 @@ func TestNoticeValidation(t *testing.T) {
 			wantErr: false,
 			wantOk:  true,
 		},
-		{
-			name: "notice with deprecating an external dependency",
-			args: args{
-				dbmsName: "mysql",
-				dbmsVer:  "5.6",
-				notice: &model.ProductNotice{
-					Conditions: model.Conditions{
-						DeprecatingDependency: &model.ExternalDependency{
-							Name:           "mysql",
-							MinimumVersion: "5.7",
-						},
-					},
-				},
-			},
-			wantErr: false,
-			wantOk:  true,
-		},
-		{
-			name: "notice with deprecating an external dependency, on a future version",
-			args: args{
-				dbmsName:      "mysql",
-				dbmsVer:       "5.6",
-				serverVersion: "5.32.1",
-				notice: &model.ProductNotice{
-					Conditions: model.Conditions{
-						ServerVersion: []string{">=v5.33"},
-						DeprecatingDependency: &model.ExternalDependency{
-							Name:           "mysql",
-							MinimumVersion: "5.7",
-						},
-					},
-				},
-			},
-			wantErr: false,
-			wantOk:  false,
-		},
 		{
 			name: "notice on a deprecating dependency, server is all good",
 			args: args{
@@ -525,23 +489,6 @@ func TestNoticeValidation(t *testing.T) {
 			wantErr: false,
 			wantOk:  false,
 		},
-		{
-			name: "notice on a deprecating dependency, server has different dbms",
-			args: args{
-				dbmsName: "mysql",
-				dbmsVer:  "5.7",
-				notice: &model.ProductNotice{
-					Conditions: model.Conditions{
-						DeprecatingDependency: &model.ExternalDependency{
-							Name:           "postgres",
-							MinimumVersion: "10",
-						},
-					},
-				},
-			},
-			wantErr: false,
-			wantOk:  false,
-		},
 		{
 			name: "notice on deprecating elasticsearch, server has unsupported search engine",
 			args: args{
