@@ -38,18 +38,14 @@ func TestGenerateSupportPacket(t *testing.T) {
 
 	th.App.UpdateConfig(func(cfg *model.Config) {
 		*cfg.LogSettings.FileLocation = dir
-		*cfg.NotificationLogSettings.FileLocation = dir
 	})
 
 	logLocation := config.GetLogFileLocation(dir)
-	notificationsLogLocation := config.GetNotificationsLogFileLocation(dir)
 
 	genMockLogFiles := func() {
 		d1 := []byte("hello\ngo\n")
 		genErr := os.WriteFile(logLocation, d1, 0777)
 		require.NoError(t, genErr)
-		genErr = os.WriteFile(notificationsLogLocation, d1, 0777)
-		require.NoError(t, genErr)
 	}
 	genMockLogFiles()
 
@@ -82,10 +78,7 @@ func TestGenerateSupportPacket(t *testing.T) {
 		expectedFileNames = append(expectedFileNames, "database_schema.yaml")
 	}
 
-	expectedFileNamesWithLogs := append(expectedFileNames, []string{
-		"mattermost.log",
-		"notifications.log",
-	}...)
+	expectedFileNamesWithLogs := append(expectedFileNames, "mattermost.log")
 
 	t.Run("generate Support Packet with logs", func(t *testing.T) {
 		fileDatas := th.App.GenerateSupportPacket(th.Context, &model.SupportPacketOptions{
@@ -109,8 +102,6 @@ func TestGenerateSupportPacket(t *testing.T) {
 	t.Run("remove the log files and ensure that warning.txt file is generated", func(t *testing.T) {
 		err = os.Remove(logLocation)
 		require.NoError(t, err)
-		err = os.Remove(notificationsLogLocation)
-		require.NoError(t, err)
 		t.Cleanup(genMockLogFiles)
 
 		fileDatas := th.App.GenerateSupportPacket(th.Context, &model.SupportPacketOptions{
@@ -385,19 +376,19 @@ func TestGetSupportPacketStats(t *testing.T) {
 
 	t.Run("Happy path", func(t *testing.T) {
 		var user *model.User
-		for i := 0; i < 4; i++ {
+		for range 4 {
 			user = th.CreateUser()
 		}
 		th.BasicUser = user
 
-		for i := 0; i < 3; i++ {
+		for range 3 {
 			deactivatedUser := th.CreateUser()
 			require.NotNil(t, deactivatedUser)
 			_, appErr := th.App.UpdateActive(th.Context, deactivatedUser, false)
 			require.Nil(t, appErr)
 		}
 
-		for i := 0; i < 2; i++ {
+		for range 2 {
 			guest := th.CreateGuest()
 			require.NotNil(t, guest)
 		}
@@ -407,7 +398,7 @@ func TestGetSupportPacketStats(t *testing.T) {
 		team := th.CreateTeam()
 		channel := th.CreateChannel(th.Context, team)
 
-		for i := 0; i < 3; i++ {
+		for range 3 {
 			p := th.CreatePost(channel)
 			require.NotNil(t, p)
 		}
@@ -462,7 +453,7 @@ func TestGetSupportPacketStats(t *testing.T) {
 			cfg.AnalyticsSettings.MaxUsersForStatistics = model.NewPointer(1)
 		})
 
-		for i := 0; i < 5; i++ {
+		for range 5 {
 			p := th.CreatePost(th.BasicChannel)
 			require.NotNil(t, p)
 		}
@@ -502,7 +493,6 @@ func TestGetSupportPacketJobList(t *testing.T) {
 		assert.Empty(t, jobs.MessageExportJobs)
 		assert.Empty(t, jobs.ElasticPostIndexingJobs)
 		assert.Empty(t, jobs.ElasticPostAggregationJobs)
-		assert.Empty(t, jobs.BlevePostIndexingJobs)
 		assert.Empty(t, jobs.MigrationJobs)
 	})
 
@@ -527,7 +517,6 @@ func TestGetSupportPacketJobList(t *testing.T) {
 			getJob(model.JobTypeMessageExport),
 			getJob(model.JobTypeElasticsearchPostIndexing),
 			getJob(model.JobTypeElasticsearchPostAggregation),
-			getJob(model.JobTypeBlevePostIndexing),
 			getJob(model.JobTypeMigrations),
 		}
 
@@ -577,13 +566,9 @@ func TestGetSupportPacketJobList(t *testing.T) {
 		require.Len(t, jobs.ElasticPostAggregationJobs, 1, "Should have 1 elasticsearch post aggregation job")
 		verifyJob(t, expectedJobs[4], jobs.ElasticPostAggregationJobs[0])
 
-		// Verify bleve post indexing jobs
-		require.Len(t, jobs.BlevePostIndexingJobs, 1, "Should have 1 bleve post indexing job")
-		verifyJob(t, expectedJobs[5], jobs.BlevePostIndexingJobs[0])
-
 		// Verify migration jobs
 		require.Len(t, jobs.MigrationJobs, 1, "Should have 1 migration job")
-		verifyJob(t, expectedJobs[6], jobs.MigrationJobs[0])
+		verifyJob(t, expectedJobs[5], jobs.MigrationJobs[0])
 	})
 }
 
