@@ -1157,13 +1157,13 @@ func TestAppUpdateTeamScheme(t *testing.T) {
 	require.NoError(t, err)
 
 	team2Scheme := th.SetupTeamScheme()
-	channelUser, appErr := th.App.GetRoleByName(context.Background(), team2Scheme.DefaultChannelUserRole)
+	channelUser, appErr := th.App.GetRoleByName(th.Context, team2Scheme.DefaultChannelUserRole)
 	require.Nil(t, appErr)
 	channelUser.Permissions = []string{}
 	_, appErr = th.App.UpdateRole(channelUser) // Remove all permissions from the team user role of the scheme
 	require.Nil(t, appErr)
 
-	channelAdmin, appErr := th.App.GetRoleByName(context.Background(), team2Scheme.DefaultChannelAdminRole)
+	channelAdmin, appErr := th.App.GetRoleByName(th.Context, team2Scheme.DefaultChannelAdminRole)
 	require.Nil(t, appErr)
 	channelAdmin.Permissions = []string{}
 	_, appErr = th.App.UpdateRole(channelAdmin) // Remove all permissions from the team admin role of the scheme
@@ -1204,7 +1204,7 @@ func TestGetTeamMembers(t *testing.T) {
 	users = append(users, *th.BasicUser)
 	users = append(users, *th.BasicUser2)
 
-	for i := 0; i < 8; i++ {
+	for i := range 8 {
 		user := model.User{
 			Email:    strings.ToLower(model.NewId()) + "success+test@example.com",
 			Username: fmt.Sprintf("user%v", i),
@@ -1513,7 +1513,7 @@ func TestClearTeamMembersCache(t *testing.T) {
 	mockStore := th.App.Srv().Store().(*mocks.Store)
 	mockTeamStore := mocks.TeamStore{}
 	tms := []*model.TeamMember{}
-	for i := 0; i < 200; i++ {
+	for range 200 {
 		tms = append(tms, &model.TeamMember{
 			TeamId: "1",
 		})
@@ -1724,7 +1724,7 @@ func TestInviteGuestsToChannelsWithPolicyEnforced(t *testing.T) {
 		ID:       channel.Id, // Use the channel ID directly
 		Name:     "Test Channel Policy",
 		Revision: 1,
-		Version:  model.AccessControlPolicyVersionV0_1,
+		Version:  model.AccessControlPolicyVersionV0_2,
 		Rules: []model.AccessControlPolicyRule{
 			{
 				Actions:    []string{"view", "join_channel"},
