@@ -655,36 +655,6 @@ func (fs SqlFileInfoStore) Search(rctx request.CTX, paramsList []*model.SearchPa
 				sq.Expr(fmt.Sprintf("to_tsvector('%[1]s', Translate(FileInfo.Name, '.,-', '   ')) @@  to_tsquery('%[1]s', ?)", fs.pgDefaultTextSearchConfig), queryTerms),
 				sq.Expr(fmt.Sprintf("to_tsvector('%[1]s', FileInfo.Content) @@  to_tsquery('%[1]s', ?)", fs.pgDefaultTextSearchConfig), queryTerms),
 			})
-		} else if fs.DriverName() == model.DatabaseDriverMysql {
-			var err error
-			terms, err = removeMysqlStopWordsFromTerms(terms)
-			if err != nil {
-				return nil, errors.Wrap(err, "failed to remove Mysql stop-words from terms")
-			}
-
-			if terms == "" {
-				return model.NewFileInfoList(), nil
-			}
-
-			excludeClause := ""
-			if excludedTerms != "" {
-				excludeClause = " -(" + excludedTerms + ")"
-			}
-
-			queryTerms := ""
-			if params.OrTerms {
-				queryTerms = terms + excludeClause
-			} else {
-				splitTerms := []string{}
-				for _, t := range strings.Fields(terms) {
-					splitTerms = append(splitTerms, "+"+t)
-				}
-				queryTerms = strings.Join(splitTerms, " ") + excludeClause
-			}
-			query = query.Where(sq.Or{
-				sq.Expr("MATCH (FileInfo.Name) AGAINST (? IN BOOLEAN MODE)", queryTerms),
-				sq.Expr("MATCH (FileInfo.Content) AGAINST (? IN BOOLEAN MODE)", queryTerms),
-			})
 		}
 	}
 
@@ -790,21 +760,10 @@ func (fs *SqlFileInfoStore) GetUptoNSizeFileTime(n int64) (int64, error) {
 		return 0, errors.New("n can't be less than 1")
 	}
 
-	var sizeSubQuery sq.SelectBuilder
-	// Separate query for MySql, as current min-version 5.x doesn't support window-functions
-	if fs.DriverName() == model.DatabaseDriverMysql {
-		sizeSubQuery = sq.
-			Select("(@runningSum := @runningSum + fi.Size) RunningTotal", "fi.CreateAt").
-			From("FileInfo fi").
-			Join("(SELECT @runningSum := 0) as tmp").
-			Where(sq.Eq{"fi.DeleteAt": 0}).
-			OrderBy("fi.CreateAt DESC, fi.Id")
-	} else {
-		sizeSubQuery = sq.
-			Select("SUM(fi.Size) OVER(ORDER BY CreateAt DESC, fi.Id) RunningTotal", "fi.CreateAt").
-			From("FileInfo fi").
-			Where(sq.Eq{"fi.DeleteAt": 0})
-	}
+	sizeSubQuery := sq.
+		Select("SUM(fi.Size) OVER(ORDER BY CreateAt DESC, fi.Id) RunningTotal", "fi.CreateAt").
+		From("FileInfo fi").
+		Where(sq.Eq{"fi.DeleteAt": 0})
 
 	builder := fs.getQueryBuilder().
 		Select("fi2.CreateAt").
