@@ -14,9 +14,7 @@ import (
 	"strings"
 	"sync"
 	"testing"
-	"time"
 
-	"github.com/go-sql-driver/mysql"
 	"github.com/lib/pq"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
@@ -71,7 +69,7 @@ func getStoresFromPools(t *testing.T) []*storeType {
 func newStoreType(name, driver string) *storeType {
 	return &storeType{
 		Name:        name,
-		SqlSettings: storetest.MakeSqlSettings(driver, false),
+		SqlSettings: storetest.MakeSqlSettings(driver),
 	}
 }
 
@@ -90,7 +88,6 @@ func StoreTest(t *testing.T, f func(*testing.T, request.CTX, store.Store)) {
 	}
 
 	for _, st := range stores {
-		st := st
 		rctx := request.TestContext(t)
 
 		t.Run(st.Name, func(t *testing.T) {
@@ -118,7 +115,6 @@ func StoreTestWithSearchTestEngine(t *testing.T, f func(*testing.T, store.Store,
 	}
 
 	for _, st := range stores {
-		st := st
 		searchTestEngine := &searchtest.SearchTestEngine{
 			Driver: *st.SqlSettings.DriverName,
 		}
@@ -144,7 +140,6 @@ func StoreTestWithSqlStore(t *testing.T, f func(*testing.T, request.CTX, store.S
 	}
 
 	for _, st := range stores {
-		st := st
 		rctx := request.TestContext(t)
 
 		t.Run(st.Name, func(t *testing.T) {
@@ -165,12 +160,9 @@ func initStores(logger mlog.LoggerIFace, parallelism int) {
 	// for subtests or paused tests that might also run in parallel and initialize a new store.
 	parallelTestsPoolSize := parallelism * 2
 
-	// In CI, we already run the entire test suite for both mysql and postgres in parallel.
-	// So we just run the tests for the current database set.
+	// In CI, we run the test suite for the current database set.
 	if os.Getenv("IS_CI") == "true" {
 		switch os.Getenv("MM_SQLSETTINGS_DRIVERNAME") {
-		case "mysql":
-			storeTypes = append(storeTypes, newStoreType("MySQL", model.DatabaseDriverMysql))
 		case "postgres":
 			storeTypes = append(storeTypes, newStoreType("PostgreSQL", model.DatabaseDriverPostgres))
 			if enableFullyParallelTests {
@@ -183,7 +175,6 @@ func initStores(logger mlog.LoggerIFace, parallelism int) {
 		}
 	} else {
 		storeTypes = append(storeTypes,
-			newStoreType("MySQL", model.DatabaseDriverMysql),
 			newStoreType("PostgreSQL", model.DatabaseDriverPostgres),
 		)
 
@@ -192,11 +183,7 @@ func initStores(logger mlog.LoggerIFace, parallelism int) {
 			if err != nil {
 				panic(err)
 			}
-			msStorePool, err := NewTestPool(logger, model.DatabaseDriverMysql, parallelTestsPoolSize)
-			if err != nil {
-				panic(err)
-			}
-			storePools = append(storePools, pgStorePool, msStorePool)
+			storePools = append(storePools, pgStorePool)
 		}
 	}
 
@@ -209,7 +196,6 @@ func initStores(logger mlog.LoggerIFace, parallelism int) {
 
 	var eg errgroup.Group
 	for _, st := range storeTypes {
-		st := st
 		eg.Go(func() error {
 			var err error
 			st.SqlStore, err = New(*st.SqlSettings, logger, nil)
@@ -238,7 +224,6 @@ func tearDownStores() {
 		var wg sync.WaitGroup
 		wg.Add(len(storeTypes))
 		for _, st := range storeTypes {
-			st := st
 			go func() {
 				if st.Store != nil {
 					st.Store.Close()
@@ -253,7 +238,6 @@ func tearDownStores() {
 		var wgPool sync.WaitGroup
 		wgPool.Add(len(storePools))
 		for _, pool := range storePools {
-			pool := pool
 			go func() {
 				defer wgPool.Done()
 				pool.Close()
@@ -393,12 +377,12 @@ func TestGetReplica(t *testing.T) {
 			store.UpdateLicense(&model.License{})
 
 			replicas := make(map[*sqlxDBWrapper]bool)
-			for i := 0; i < 5; i++ {
+			for range 5 {
 				replicas[store.GetReplica()] = true
 			}
 
 			searchReplicas := make(map[*sqlxDBWrapper]bool)
-			for i := 0; i < 5; i++ {
+			for range 5 {
 				searchReplicas[store.GetSearchReplicaX()] = true
 			}
 
@@ -464,12 +448,12 @@ func TestGetReplica(t *testing.T) {
 			}()
 
 			replicas := make(map[*sqlxDBWrapper]bool)
-			for i := 0; i < 5; i++ {
+			for range 5 {
 				replicas[store.GetReplica()] = true
 			}
 
 			searchReplicas := make(map[*sqlxDBWrapper]bool)
-			for i := 0; i < 5; i++ {
+			for range 5 {
 				searchReplicas[store.GetSearchReplicaX()] = true
 			}
 
@@ -518,7 +502,6 @@ func TestGetDbVersion(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	for _, d := range testDrivers {
@@ -560,6 +543,24 @@ func TestEnsureMinimumDBVersion(t *testing.T) {
 		{
 			driver: model.DatabaseDriverPostgres,
 			ver:    "130001",
+			ok:     false,
+			err:    "",
+		},
+		{
+			driver: model.DatabaseDriverPostgres,
+			ver:    "140000",
+			ok:     true,
+			err:    "",
+		},
+		{
+			driver: model.DatabaseDriverPostgres,
+			ver:    "141900",
+			ok:     true,
+			err:    "",
+		},
+		{
+			driver: model.DatabaseDriverPostgres,
+			ver:    "150000",
 			ok:     true,
 			err:    "",
 		},
@@ -575,48 +576,15 @@ func TestEnsureMinimumDBVersion(t *testing.T) {
 			ok:     false,
 			err:    "cannot parse DB version",
 		},
-		{
-			driver: model.DatabaseDriverMysql,
-			ver:    "10.4.5-MariaDB",
-			ok:     true,
-			err:    "",
-		},
-		{
-			driver: model.DatabaseDriverMysql,
-			ver:    "5.6.99-test",
-			ok:     false,
-			err:    "Minimum MySQL version requirements not met",
-		},
-		{
-			driver: model.DatabaseDriverMysql,
-			ver:    "34-55.12",
-			ok:     false,
-			err:    "cannot parse MySQL DB version",
-		},
-		{
-			driver: model.DatabaseDriverMysql,
-			ver:    "8.0.0-log",
-			ok:     true,
-			err:    "",
-		},
 	}
 
 	pg := model.DatabaseDriverPostgres
 	pgSettings := &model.SqlSettings{
 		DriverName: &pg,
 	}
-	my := model.DatabaseDriverMysql
-	mySettings := &model.SqlSettings{
-		DriverName: &my,
-	}
 	for _, tc := range tests {
 		store := &SqlStore{}
-		switch tc.driver {
-		case pg:
-			store.settings = pgSettings
-		case my:
-			store.settings = mySettings
-		}
+		store.settings = pgSettings
 		ok, err := store.ensureMinimumDBVersion(tc.ver)
 		assert.Equal(t, tc.ok, ok, "driver: %s, version: %s", tc.driver, tc.ver)
 		if tc.err != "" {
@@ -643,15 +611,6 @@ func TestIsBinaryParamEnabled(t *testing.T) {
 			},
 			expected: true,
 		},
-		{
-			store: SqlStore{
-				settings: &model.SqlSettings{
-					DriverName: model.NewPointer(model.DatabaseDriverMysql),
-					DataSource: model.NewPointer("postgres://mmuser:mostest@localhost/loadtest?sslmode=disable\u0026binary_parameters=yes"),
-				},
-			},
-			expected: false,
-		},
 		{
 			store: SqlStore{
 				settings: &model.SqlSettings{
@@ -782,11 +741,9 @@ func TestIsDuplicate(t *testing.T) {
 	}
 
 	testErrors := map[error]bool{
-		&pq.Error{Code: "42P06"}:                          false,
-		&pq.Error{Code: PGDupTableErrorCode}:              true,
-		&mysql.MySQLError{Number: uint16(1000)}:           false,
-		&mysql.MySQLError{Number: MySQLDupTableErrorCode}: true,
-		errors.New("Random error"):                        false,
+		&pq.Error{Code: "42P06"}:             false,
+		&pq.Error{Code: PGDupTableErrorCode}: true,
+		errors.New("Random error"):           false,
 	}
 
 	for e, b := range testErrors {
@@ -824,16 +781,6 @@ func TestVersionString(t *testing.T) {
 			driver: model.DatabaseDriverPostgres,
 			output: "12.5",
 		},
-		{
-			input:  5708,
-			driver: model.DatabaseDriverMysql,
-			output: "5.7.8",
-		},
-		{
-			input:  8000,
-			driver: model.DatabaseDriverMysql,
-			output: "8.0.0",
-		},
 	}
 
 	for _, v := range versions {
@@ -849,7 +796,6 @@ func TestReplicaLagQuery(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	for _, driver := range testDrivers {
@@ -865,9 +811,6 @@ func TestReplicaLagQuery(t *testing.T) {
 			case model.DatabaseDriverPostgres:
 				query = `SELECT relname, count(relname) FROM pg_class WHERE relname='posts' GROUP BY relname`
 				tableName = "posts"
-			case model.DatabaseDriverMysql:
-				query = `SELECT table_name, count(table_name) FROM information_schema.tables WHERE table_name='Posts' and table_schema=Database() GROUP BY table_name`
-				tableName = "Posts"
 			}
 
 			settings.ReplicaLagSettings = []*model.ReplicaLagSettings{{
@@ -916,7 +859,6 @@ func TestInvalidReplicaLagDataSource(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	for _, driver := range testDrivers {
@@ -972,9 +914,7 @@ func makeSqlSettings(driver string) (*model.SqlSettings, error) {
 
 	switch driver {
 	case model.DatabaseDriverPostgres:
-		return storetest.MakeSqlSettings(driver, false), nil
-	case model.DatabaseDriverMysql:
-		return storetest.MakeSqlSettings(driver, false), nil
+		return storetest.MakeSqlSettings(driver), nil
 	}
 
 	return nil, errDriverUnsupported
@@ -983,48 +923,17 @@ func makeSqlSettings(driver string) (*model.SqlSettings, error) {
 func TestExecNoTimeout(t *testing.T) {
 	StoreTest(t, func(t *testing.T, rctx request.CTX, ss store.Store) {
 		sqlStore := ss.(*SqlStore)
-		var query string
 		timeout := sqlStore.masterX.queryTimeout
 		sqlStore.masterX.queryTimeout = 1
 		defer func() {
 			sqlStore.masterX.queryTimeout = timeout
 		}()
-		if sqlStore.DriverName() == model.DatabaseDriverMysql {
-			query = `SELECT SLEEP(2);`
-		} else if sqlStore.DriverName() == model.DatabaseDriverPostgres {
-			query = `SELECT pg_sleep(2);`
-		}
+		query := `SELECT pg_sleep(2);`
 		_, err := sqlStore.GetMaster().ExecNoTimeout(query)
 		require.NoError(t, err)
 	})
 }
 
-func TestMySQLReadTimeout(t *testing.T) {
-	settings, err := makeSqlSettings(model.DatabaseDriverMysql)
-	if err != nil {
-		t.Skip(err)
-	}
-	dataSource := *settings.DataSource
-	config, err := mysql.ParseDSN(dataSource)
-	require.NoError(t, err)
-
-	config.ReadTimeout = 1 * time.Second
-	dataSource = config.FormatDSN()
-	settings.DataSource = &dataSource
-
-	store := &SqlStore{
-		settings:    settings,
-		logger:      mlog.CreateConsoleTestLogger(t),
-		quitMonitor: make(chan struct{}),
-		wgMonitor:   &sync.WaitGroup{},
-	}
-	require.NoError(t, store.initConnection())
-	defer store.Close()
-
-	_, err = store.GetMaster().ExecNoTimeout(`SELECT SLEEP(3)`)
-	require.NoError(t, err)
-}
-
 func TestGetDBSchemaVersion(t *testing.T) {
 	if enableFullyParallelTests {
 		t.Parallel()
@@ -1032,7 +941,6 @@ func TestGetDBSchemaVersion(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	logger := mlog.CreateConsoleTestLogger(t)
@@ -1076,7 +984,6 @@ func TestGetLocalSchemaVersion(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	logger := mlog.CreateConsoleTestLogger(t)
@@ -1108,7 +1015,6 @@ func TestGetAppliedMigrations(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	logger := mlog.CreateConsoleTestLogger(t)
@@ -1160,7 +1066,6 @@ func TestSkipMigrationsOption(t *testing.T) {
 
 	testDrivers := []string{
 		model.DatabaseDriverPostgres,
-		model.DatabaseDriverMysql,
 	}
 
 	logger := mlog.CreateConsoleTestLogger(t)
@@ -1184,12 +1089,7 @@ func TestSkipMigrationsOption(t *testing.T) {
 			assert.True(t, !errors.Is(err, sql.ErrNoRows))
 
 			// And we know what each db will return:
-			if driver == model.DatabaseDriverPostgres {
-				assert.Contains(t, err.Error(), "pq: relation \"db_migrations\" does not exist")
-			} else {
-				// Mysql includes the random db name, so test the end:
-				assert.Contains(t, err.Error(), ".db_migrations' doesn't exist")
-			}
+			assert.Contains(t, err.Error(), "pq: relation \"db_migrations\" does not exist")
 		})
 	}
 }
