@@ -27,6 +27,7 @@ import (
 
 const (
 	MaxGroupChannelsForProfiles = 50
+	ContentReviewerSearchLimit  = 50
 )
 
 var (
@@ -89,6 +90,14 @@ func getUsersColumns() []string {
 	}
 }
 
+func getBotInfoColumns() []string {
+	return []string{
+		"b.UserId IS NOT NULL AS IsBot",
+		"COALESCE(b.Description, '') AS BotDescription",
+		"COALESCE(b.LastIconUpdate, 0) AS BotLastIconUpdate",
+	}
+}
+
 func newSqlUserStore(sqlStore *SqlStore, metrics einterfaces.MetricsInterface) store.UserStore {
 	us := &SqlUserStore{
 		SqlStore: sqlStore,
@@ -99,11 +108,7 @@ func newSqlUserStore(sqlStore *SqlStore, metrics einterfaces.MetricsInterface) s
 		// Together with getUsersColumns, the order specified here must match
 		// with [SqlUserStore.Get] and [SqlUserStore.GetAllProfilesInChannel].
 		Select(getUsersColumns()...).
-		Columns(
-			"b.UserId IS NOT NULL AS IsBot",
-			"COALESCE(b.Description, '') AS BotDescription",
-			"COALESCE(b.LastIconUpdate, 0) AS BotLastIconUpdate",
-		).
+		Columns(getBotInfoColumns()...).
 		From("Users").
 		LeftJoin("Bots b ON ( b.UserId = Users.Id )")
 
@@ -244,18 +249,29 @@ func (us SqlUserStore) Update(rctx request.CTX, user *model.User, trustedUpdateD
 	if !trustedUpdateData {
 		user.Roles = oldUser.Roles
 		user.DeleteAt = oldUser.DeleteAt
-	}
 
-	if user.IsOAuthUser() {
-		if !trustedUpdateData {
+		if user.IsOAuthUser() {
 			user.Email = oldUser.Email
 		}
-	} else if user.IsLDAPUser() && !trustedUpdateData {
-		if user.Username != oldUser.Username || user.Email != oldUser.Email {
-			return nil, store.NewErrInvalidInput("User", "id", user.Id)
+
+		if user.IsLDAPUser() {
+			if user.Username != oldUser.Username {
+				return nil, store.NewErrInvalidInput("User", "id", user.Id)
+			}
+			if user.Email != oldUser.Email {
+				return nil, store.NewErrInvalidInput("User", "email", user.Id)
+			}
 		}
-	} else if user.Email != oldUser.Email {
-		user.EmailVerified = false
+
+		if user.Email != oldUser.Email {
+			user.EmailVerified = false
+		}
+	}
+
+	// In the past, changing the email of a SSO user would mark the email as unverified.
+	// This is a lazy migration to fix broken records.
+	if user.IsSSOUser() {
+		user.EmailVerified = true
 	}
 
 	if user.Username != oldUser.Username {
@@ -499,10 +515,10 @@ func (us SqlUserStore) GetMfaUsedTimestamps(userId string) ([]int, error) {
 }
 
 // GetMany returns a list of users for the provided list of ids
-func (us SqlUserStore) GetMany(ctx context.Context, ids []string) ([]*model.User, error) {
+func (us SqlUserStore) GetMany(rctx request.CTX, ids []string) ([]*model.User, error) {
 	query := us.usersQuery.Where(sq.Eq{"Id": ids})
 	users := []*model.User{}
-	if err := us.SqlStore.DBXFromContext(ctx).SelectBuilderCtx(ctx, &users, query); err != nil {
+	if err := us.SqlStore.DBXFromContext(rctx.Context()).SelectBuilderCtx(rctx.Context(), &users, query); err != nil {
 		return nil, errors.Wrap(err, "users_get_many_select")
 	}
 
@@ -1102,7 +1118,7 @@ func (us SqlUserStore) GetNewUsersForTeam(teamId string, offset, limit int, view
 	return users, nil
 }
 
-func (us SqlUserStore) GetProfileByIds(ctx context.Context, userIds []string, options *store.UserGetByIdsOpts, allowFromCache bool) ([]*model.User, error) {
+func (us SqlUserStore) GetProfileByIds(rctx request.CTX, userIds []string, options *store.UserGetByIdsOpts, allowFromCache bool) ([]*model.User, error) {
 	if options == nil {
 		options = &store.UserGetByIdsOpts{}
 	}
@@ -1127,7 +1143,7 @@ func (us SqlUserStore) GetProfileByIds(ctx context.Context, userIds []string, op
 		return nil, errors.Wrap(err, "get_profile_by_ids_tosql")
 	}
 
-	if err := us.SqlStore.DBXFromContext(ctx).Select(&users, queryString, args...); err != nil {
+	if err := us.SqlStore.DBXFromContext(rctx.Context()).Select(&users, queryString, args...); err != nil {
 		return nil, errors.Wrap(err, "failed to find Users")
 	}
 
@@ -1560,6 +1576,47 @@ func (us SqlUserStore) Search(rctx request.CTX, teamId string, term string, opti
 	return us.performSearch(query, term, options)
 }
 
+func (us SqlUserStore) SearchCommonContentFlaggingReviewers(term string) ([]*model.User, error) {
+	query := us.getQueryBuilder().
+		Select(getUsersColumns()...).
+		Columns(getBotInfoColumns()...).
+		From("ContentFlaggingCommonReviewers").
+		LeftJoin("Users ON Users.Id = ContentFlaggingCommonReviewers.UserId").
+		LeftJoin("Bots b ON (b.UserId = Users.Id)").
+		OrderBy("Users.Username ASC").
+		Limit(ContentReviewerSearchLimit)
+
+	searchOptions := &model.UserSearchOptions{
+		AllowEmails:    false,
+		AllowFullNames: true,
+		AllowInactive:  false,
+		Limit:          50,
+	}
+
+	return us.performSearch(query, term, searchOptions)
+}
+
+func (us SqlUserStore) SearchTeamContentFlaggingReviewers(teamId, term string) ([]*model.User, error) {
+	query := us.getQueryBuilder().
+		Select(getUsersColumns()...).
+		Columns(getBotInfoColumns()...).
+		From("ContentFlaggingTeamReviewers").
+		LeftJoin("Users ON Users.Id = ContentFlaggingTeamReviewers.UserId").
+		LeftJoin("Bots b ON (b.UserId = Users.Id)").
+		Where("ContentFlaggingTeamReviewers.TeamId = ?", teamId).
+		OrderBy("Users.Username ASC").
+		Limit(ContentReviewerSearchLimit)
+
+	searchOptions := &model.UserSearchOptions{
+		AllowEmails:    false,
+		AllowFullNames: true,
+		AllowInactive:  false,
+		Limit:          50,
+	}
+
+	return us.performSearch(query, term, searchOptions)
+}
+
 func (us SqlUserStore) SearchWithoutTeam(term string, options *model.UserSearchOptions) ([]*model.User, error) {
 	query := us.usersQuery.
 		Where(`(
@@ -1837,7 +1894,7 @@ func (us SqlUserStore) ClearAllCustomRoleAssignments() (err error) {
 
 			var newRoles []string
 
-			for _, role := range strings.Fields(user.Roles) {
+			for role := range strings.FieldsSeq(user.Roles) {
 				for name := range builtInRoles {
 					if name == role {
 						newRoles = append(newRoles, role)
