@@ -98,7 +98,7 @@ func testThreadStorePopulation(t *testing.T, rctx request.CTX, ss store.Store) {
 		opts := model.GetPostsOptions{
 			SkipFetchThreads: true,
 		}
-		olist, _ := ss.Post().Get(context.Background(), otmp.Id, opts, "", map[string]bool{})
+		olist, _ := ss.Post().Get(rctx, otmp.Id, opts, "", map[string]bool{})
 		o1 := olist.Posts[olist.Order[0]]
 
 		newPosts = append([]*model.Post{o1}, newPosts...)
@@ -379,14 +379,14 @@ func testThreadStorePopulation(t *testing.T, rctx request.CTX, ss store.Store) {
 		}
 		m, err := ss.Thread().MaintainMembership(newPosts[0].UserId, newPosts[0].Id, opts)
 		require.NoError(t, err)
-		th, err := ss.Thread().GetThreadForUser(m, false, false)
+		th, err := ss.Thread().GetThreadForUser(rctx, m, false, false)
 		require.NoError(t, err)
 		require.Equal(t, int64(2), th.UnreadReplies)
 
 		m.LastViewed = newPosts[2].UpdateAt + 1
 		_, err = ss.Thread().UpdateMembership(m)
 		require.NoError(t, err)
-		th, err = ss.Thread().GetThreadForUser(m, false, false)
+		th, err = ss.Thread().GetThreadForUser(rctx, m, false, false)
 		require.NoError(t, err)
 		require.Equal(t, int64(0), th.UnreadReplies)
 
@@ -395,7 +395,7 @@ func testThreadStorePopulation(t *testing.T, rctx request.CTX, ss store.Store) {
 		_, err = ss.Post().Update(rctx, editedPost, newPosts[2])
 		require.NoError(t, err)
 
-		th, err = ss.Thread().GetThreadForUser(m, false, false)
+		th, err = ss.Thread().GetThreadForUser(rctx, m, false, false)
 		require.NoError(t, err)
 		require.Equal(t, int64(0), th.UnreadReplies)
 	})
@@ -412,7 +412,7 @@ func testThreadStorePopulation(t *testing.T, rctx request.CTX, ss store.Store) {
 		m, err := ss.Thread().MaintainMembership("", newPosts[0].Id, opts)
 		require.NoError(t, err)
 		m.UserId = newPosts[0].UserId
-		th, err := ss.Thread().GetThreadForUser(m, true, false)
+		th, err := ss.Thread().GetThreadForUser(rctx, m, true, false)
 		require.NoError(t, err)
 		for _, user := range th.Participants {
 			require.NotNil(t, user)
@@ -469,11 +469,11 @@ func testThreadStorePopulation(t *testing.T, rctx request.CTX, ss store.Store) {
 			m, e := ss.Thread().GetMembershipForUser(userID, newPosts[0].Id)
 			require.NoError(t, e)
 
-			th, e := ss.Thread().GetThreadForUser(m, false, true)
+			th, e := ss.Thread().GetThreadForUser(rctx, m, false, true)
 			require.NoError(t, e)
 			require.Equal(t, isUrgent, th.IsUrgent)
 
-			threads, e := ss.Thread().GetThreadsForUser(userID, "", model.GetUserThreadsOpts{IncludeIsUrgent: true})
+			threads, e := ss.Thread().GetThreadsForUser(rctx, userID, "", model.GetUserThreadsOpts{IncludeIsUrgent: true})
 			require.NoError(t, e)
 			require.Equal(t, isUrgent, threads[0].IsUrgent)
 		})
@@ -1238,7 +1238,7 @@ func testVarious(t *testing.T, rctx request.CTX, ss store.Store) {
 
 		for _, testCase := range testCases {
 			t.Run(testCase.Description, func(t *testing.T) {
-				threads, err := ss.Thread().GetThreadsForUser(testCase.UserID, testCase.TeamID, testCase.Options)
+				threads, err := ss.Thread().GetThreadsForUser(rctx, testCase.UserID, testCase.TeamID, testCase.Options)
 				require.NoError(t, err)
 
 				assertThreadPosts(t, threads, testCase.ExpectedThreads)
@@ -2121,7 +2121,7 @@ func testUpdateTeamIdForChannelThreads(t *testing.T, rctx request.CTX, ss store.
 			require.NoError(t, err)
 		}()
 
-		threads, err := ss.Thread().GetThreadsForUser(userA.Id, team2.Id, model.GetUserThreadsOpts{})
+		threads, err := ss.Thread().GetThreadsForUser(rctx, userA.Id, team2.Id, model.GetUserThreadsOpts{})
 		require.NoError(t, err)
 		require.Len(t, threads, 1)
 	})
@@ -2142,11 +2142,11 @@ func testUpdateTeamIdForChannelThreads(t *testing.T, rctx request.CTX, ss store.
 		err = ss.Thread().UpdateTeamIdForChannelThreads(channel1.Id, newTeamID)
 		require.NoError(t, err)
 
-		threads, err := ss.Thread().GetThreadsForUser(userA.Id, newTeamID, model.GetUserThreadsOpts{})
+		threads, err := ss.Thread().GetThreadsForUser(rctx, userA.Id, newTeamID, model.GetUserThreadsOpts{})
 		require.NoError(t, err)
 		require.Len(t, threads, 0)
 
-		threads, err = ss.Thread().GetThreadsForUser(userA.Id, team1.Id, model.GetUserThreadsOpts{})
+		threads, err = ss.Thread().GetThreadsForUser(rctx, userA.Id, team1.Id, model.GetUserThreadsOpts{})
 		require.NoError(t, err)
 		require.Len(t, threads, 1)
 	})
