@@ -335,7 +335,7 @@ func TestHandlerServeCSPHeader(t *testing.T) {
 		response := httptest.NewRecorder()
 		handler.ServeHTTP(response, request)
 		assert.Equal(t, 200, response.Code)
-		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self' cdn.rudderlabs.com"}, response.Header()["Content-Security-Policy"])
+		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self'"}, response.Header()["Content-Security-Policy"])
 	})
 
 	t.Run("static, with subpath and frame ancestors", func(t *testing.T) {
@@ -376,12 +376,12 @@ func TestHandlerServeCSPHeader(t *testing.T) {
 		response := httptest.NewRecorder()
 		handler.ServeHTTP(response, request)
 		assert.Equal(t, 200, response.Code)
-		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self' cdn.rudderlabs.com"}, response.Header()["Content-Security-Policy"])
+		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self'"}, response.Header()["Content-Security-Policy"])
 
 		// TODO: It's hard to unit test this now that the CSP directive is effectively
 		// decided in Setup(). Circle back to this in master once the memory store is
 		// merged, allowing us to mock the desired initial config to take effect in Setup().
-		// assert.Contains(t, response.Header()["Content-Security-Policy"], "frame-ancestors 'self'; script-src 'self' cdn.rudderlabs.com 'sha256-tPOjw+tkVs9axL78ZwGtYl975dtyPHB6LYKAO2R3gR4='")
+		// assert.Contains(t, response.Header()["Content-Security-Policy"], "frame-ancestors 'self'; script-src 'self' 'sha256-tPOjw+tkVs9axL78ZwGtYl975dtyPHB6LYKAO2R3gR4='")
 
 		th.App.UpdateConfig(func(cfg *model.Config) {
 			*cfg.ServiceSettings.SiteURL = *cfg.ServiceSettings.SiteURL + "/subpath2"
@@ -391,9 +391,9 @@ func TestHandlerServeCSPHeader(t *testing.T) {
 		response = httptest.NewRecorder()
 		handler.ServeHTTP(response, request)
 		assert.Equal(t, 200, response.Code)
-		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self' cdn.rudderlabs.com"}, response.Header()["Content-Security-Policy"])
+		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self'"}, response.Header()["Content-Security-Policy"])
 		// TODO: See above.
-		// assert.Contains(t, response.Header()["Content-Security-Policy"], "frame-ancestors 'self'; script-src 'self' cdn.rudderlabs.com 'sha256-tPOjw+tkVs9axL78ZwGtYl975dtyPHB6LYKAO2R3gR4='", "csp header incorrectly changed after subpath changed")
+		// assert.Contains(t, response.Header()["Content-Security-Policy"], "frame-ancestors 'self'; script-src 'self' 'sha256-tPOjw+tkVs9axL78ZwGtYl975dtyPHB6LYKAO2R3gR4='", "csp header incorrectly changed after subpath changed")
 	})
 
 	t.Run("dev mode", func(t *testing.T) {
@@ -420,7 +420,7 @@ func TestHandlerServeCSPHeader(t *testing.T) {
 		response := httptest.NewRecorder()
 		handler.ServeHTTP(response, request)
 		assert.Equal(t, 200, response.Code)
-		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self' cdn.rudderlabs.com 'unsafe-eval' 'unsafe-inline'"}, response.Header()["Content-Security-Policy"])
+		assert.Equal(t, []string{"frame-ancestors 'self' " + *th.App.Config().ServiceSettings.FrameAncestors + "; script-src 'self' 'unsafe-eval' 'unsafe-inline'"}, response.Header()["Content-Security-Policy"])
 	})
 }
 
@@ -585,6 +585,72 @@ func TestHandlerServeInvalidToken(t *testing.T) {
 	}
 }
 
+func TestHandlerServeCSRFFailureClearsAuthCookie(t *testing.T) {
+	testCases := []struct {
+		Description                       string
+		SiteURL                           string
+		ExpectedSetCookieHeaderRegexp     string
+		ExperimentalStrictCSRFEnforcement bool
+	}{
+		{"no subpath", "http://localhost:8065", "^MMAUTHTOKEN=; Path=/", false},
+		{"subpath", "http://localhost:8065/subpath", "^MMAUTHTOKEN=; Path=/subpath", false},
+		{"no subpath", "http://localhost:8065", "^MMAUTHTOKEN=; Path=/", true},
+		{"subpath", "http://localhost:8065/subpath", "^MMAUTHTOKEN=; Path=/subpath", true},
+	}
+
+	for _, tc := range testCases {
+		t.Run(tc.Description, func(t *testing.T) {
+			th := Setup(t).InitBasic(t)
+
+			th.App.UpdateConfig(func(cfg *model.Config) {
+				*cfg.ServiceSettings.SiteURL = tc.SiteURL
+				*cfg.ServiceSettings.ExperimentalStrictCSRFEnforcement = tc.ExperimentalStrictCSRFEnforcement
+			})
+
+			session := &model.Session{
+				UserId:   th.BasicUser.Id,
+				CreateAt: model.GetMillis(),
+				Roles:    model.SystemUserRoleId,
+				IsOAuth:  false,
+			}
+			session.GenerateCSRF()
+			th.App.SetSessionExpireInHours(session, 24)
+			var err *model.AppError
+			session, err = th.App.CreateSession(th.Context, session)
+			require.Nil(t, err)
+
+			web := New(th.Server)
+			handler := Handler{
+				Srv:            web.srv,
+				HandleFunc:     handlerForCSRFToken,
+				RequireSession: true,
+				TrustRequester: false,
+				RequireMfa:     false,
+				IsStatic:       false,
+			}
+
+			cookie := &http.Cookie{
+				Name:  model.SessionCookieToken,
+				Value: session.Token,
+			}
+
+			request := httptest.NewRequest("POST", "/api/v4/test", nil)
+			request.AddCookie(cookie)
+			request.Header.Add(model.HeaderRequestedWith, model.HeaderRequestedWithXML)
+			response := httptest.NewRecorder()
+			handler.ServeHTTP(response, request)
+
+			if tc.ExperimentalStrictCSRFEnforcement {
+				require.Equal(t, http.StatusUnauthorized, response.Code)
+				cookies := response.Header().Get("Set-Cookie")
+				assert.Regexp(t, tc.ExpectedSetCookieHeaderRegexp, cookies)
+			} else {
+				require.Equal(t, http.StatusOK, response.Code)
+			}
+		})
+	}
+}
+
 func TestCheckCSRFToken(t *testing.T) {
 	t.Run("should allow a POST request with a valid CSRF token header", func(t *testing.T) {
 		th := SetupWithStoreMock(t)
@@ -609,7 +675,7 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.True(t, checked)
 		assert.True(t, passed)
@@ -640,7 +706,7 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.True(t, checked)
 		assert.True(t, passed)
@@ -690,11 +756,11 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.True(t, checked)
 		assert.False(t, passed)
-		assert.NotNil(t, c.Err)
+		assert.Nil(t, c.Err)
 	})
 
 	t.Run("should not allow a POST request without either header", func(t *testing.T) {
@@ -719,11 +785,11 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.True(t, checked)
 		assert.False(t, passed)
-		assert.NotNil(t, c.Err)
+		assert.Nil(t, c.Err)
 	})
 
 	t.Run("should not check GET requests", func(t *testing.T) {
@@ -748,7 +814,7 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.False(t, checked)
 		assert.False(t, passed)
@@ -777,7 +843,7 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.False(t, checked)
 		assert.False(t, passed)
@@ -802,7 +868,7 @@ func TestCheckCSRFToken(t *testing.T) {
 		r, _ := http.NewRequest(http.MethodPost, "", nil)
 		r.Header.Set(model.HeaderCsrfToken, token)
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, nil)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, nil)
 
 		assert.False(t, checked)
 		assert.False(t, passed)
@@ -832,7 +898,7 @@ func TestCheckCSRFToken(t *testing.T) {
 			},
 		}
 
-		checked, passed := h.checkCSRFToken(c, r, token, tokenLocation, session)
+		checked, passed := h.checkCSRFToken(c, r, tokenLocation, session)
 
 		assert.True(t, checked)
 		assert.True(t, passed)
