@@ -338,7 +338,7 @@ func (s *MmctlE2ETestSuite) TestComplianceExportDownloadCmdE2E() {
 		cmd := makeCmd()
 		cmd.Flags().Int("num-retries", 0, "")
 		err = complianceExportDownloadCmdF(s.th.Client, cmd, []string{job.Id})
-		s.Require().EqualError(err, "failed to download compliance export file: You do not have the appropriate permissions.")
+		s.Require().EqualError(err, "failed to download compliance export after 0 retries: You do not have the appropriate permissions.")
 		s.Require().Empty(printer.GetLines())
 		s.Require().Empty(printer.GetErrorLines())
 	})
@@ -349,7 +349,7 @@ func (s *MmctlE2ETestSuite) TestComplianceExportDownloadCmdE2E() {
 		cmd := makeCmd()
 		cmd.Flags().Int("num-retries", 0, "")
 		err := complianceExportDownloadCmdF(c, cmd, []string{"non-existent-job-id"})
-		s.Require().EqualError(err, "failed to download compliance export file: Sorry, we could not find the page., There doesn't appear to be an api call for the url='/api/v4/jobs/non-existent-job-id/download'.  Typo? are you missing a team_id or user_id as part of the url?")
+		s.Require().EqualError(err, "failed to download compliance export after 0 retries: Sorry, we could not find the page., There doesn't appear to be an api call for the url='/api/v4/jobs/non-existent-job-id/download'.  Typo? are you missing a team_id or user_id as part of the url?")
 		s.Require().Empty(printer.GetLines())
 		s.Require().Empty(printer.GetErrorLines())
 	})
