@@ -215,7 +215,7 @@ func (s *MmctlE2ETestSuite) TestListUserCmd() {
 		s.th.SystemAdminUser.Username,
 		s.th.SystemManagerUser.Username,
 	}
-	for i := 0; i < 10; i++ {
+	for range 10 {
 		userData := model.User{
 			Username: "fakeuser" + model.NewRandomString(10),
 			Password: "Pa$$word11",
@@ -228,7 +228,7 @@ func (s *MmctlE2ETestSuite) TestListUserCmd() {
 
 	inactivePool := []string{}
 	// create inactive users
-	for i := 0; i < 2; i++ {
+	for range 2 {
 		userData := model.User{
 			Username: "fakeuser" + model.NewRandomString(10),
 			Password: "Pa$$word11",
@@ -294,7 +294,7 @@ func (s *MmctlE2ETestSuite) TestListUserCmd() {
 	})
 
 	// create users with team
-	for i := 0; i < 10; i++ {
+	for range 10 {
 		userData := model.User{
 			Username: "teamuser" + model.NewRandomString(10),
 			Password: "Pa$$word11",
@@ -327,7 +327,7 @@ func (s *MmctlE2ETestSuite) TestListUserCmd() {
 	// create inactive users with team
 	inactiveUserPool := []string{}
 
-	for i := 0; i < 10; i++ {
+	for range 10 {
 		userData := model.User{
 			Username: "inactiveteamuser" + model.NewRandomString(10),
 			Password: "Pa$$word11",
@@ -667,95 +667,6 @@ func (s *MmctlE2ETestSuite) TestCreateUserCmd() {
 	})
 }
 
-func (s *MmctlE2ETestSuite) TestUpdateUserEmailCmd() {
-	s.SetupTestHelper().InitBasic()
-
-	s.RunForSystemAdminAndLocal("admin and local user can change user email", func(c client.Client) {
-		printer.Clean()
-		oldEmail := s.th.BasicUser2.Email
-		newEmail := "basicuser2@fakedomain.com"
-		err := updateUserEmailCmdF(c, &cobra.Command{}, []string{s.th.BasicUser2.Email, newEmail})
-		s.Require().Nil(err)
-
-		u, err := s.th.App.GetUser(s.th.BasicUser2.Id)
-		s.Require().Nil(err)
-		s.Require().Equal(newEmail, u.Email)
-
-		u.Email = oldEmail
-		_, err = s.th.App.UpdateUser(s.th.Context, u, false)
-		s.Require().Nil(err)
-	})
-
-	s.Run("normal user doesn't have permission to change another user's email", func() {
-		printer.Clean()
-		newEmail := "basicuser2-change@fakedomain.com"
-		err := updateUserEmailCmdF(s.th.Client, &cobra.Command{}, []string{s.th.BasicUser2.Id, newEmail})
-		s.Require().EqualError(err, "You do not have the appropriate permissions.")
-
-		u, err := s.th.App.GetUser(s.th.BasicUser2.Id)
-		s.Require().Nil(err)
-		s.Require().Equal(s.th.BasicUser2.Email, u.Email)
-	})
-
-	s.Run("normal users can't update their own email due to security reasons", func() {
-		printer.Clean()
-
-		newEmail := "basicuser-change@fakedomain.com"
-		err := updateUserEmailCmdF(s.th.Client, &cobra.Command{}, []string{s.th.BasicUser.Id, newEmail})
-		s.Require().EqualError(err, "Invalid or missing password in request body.")
-	})
-}
-
-func (s *MmctlE2ETestSuite) TestUpdateUsernameCmd() {
-	s.SetupTestHelper().InitBasic()
-
-	s.RunForSystemAdminAndLocal("admin and local user can change user name", func(c client.Client) {
-		printer.Clean()
-		oldName := s.th.BasicUser2.Username
-		newName := "basicusernamechange"
-		err := updateUsernameCmdF(c, &cobra.Command{}, []string{s.th.BasicUser2.Username, newName})
-		s.Require().Nil(err)
-
-		u, err := s.th.App.GetUser(s.th.BasicUser2.Id)
-		s.Require().Nil(err)
-		s.Require().Equal(newName, u.Username)
-
-		u.Username = oldName
-		_, err = s.th.App.UpdateUser(s.th.Context, u, false)
-		s.Require().Nil(err)
-	})
-
-	s.Run("normal user doesn't have permission to change another user's name", func() {
-		printer.Clean()
-		newUsername := "basicusernamechange"
-		err := updateUsernameCmdF(s.th.Client, &cobra.Command{}, []string{s.th.BasicUser2.Id, newUsername})
-		s.Require().EqualError(err, "You do not have the appropriate permissions.")
-
-		u, err := s.th.App.GetUser(s.th.BasicUser2.Id)
-		s.Require().Nil(err)
-		s.Require().Equal(s.th.BasicUser2.Username, u.Username)
-	})
-
-	s.Run("Can't change by a invalid username", func() {
-		printer.Clean()
-		newUsername := "invalid username"
-		err := updateUsernameCmdF(s.th.Client, &cobra.Command{}, []string{s.th.BasicUser2.Id, newUsername})
-		s.Require().EqualError(err, "invalid username: '"+newUsername+"'")
-
-		u, err := s.th.App.GetUser(s.th.BasicUser2.Id)
-		s.Require().Nil(err)
-		s.Require().Equal(s.th.BasicUser2.Username, u.Username)
-	})
-
-	s.RunForSystemAdminAndLocal("Delete nonexistent user", func(c client.Client) {
-		printer.Clean()
-		oldName := "nonexistentuser"
-		newUsername := "basicusernamechange"
-		err := updateUsernameCmdF(s.th.Client, &cobra.Command{}, []string{oldName, newUsername})
-		s.Require().EqualError(err, "unable to find user '"+oldName+"'")
-	})
-}
-
 func (s *MmctlE2ETestSuite) TestDeleteUsersCmd() {
 	s.SetupTestHelper().InitBasic()
 
@@ -1037,7 +948,7 @@ func (s *MmctlE2ETestSuite) TestDeleteAllUserCmd() {
 		printer.Clean()
 
 		// populate with some user
-		for i := 0; i < 10; i++ {
+		for range 10 {
 			userData := model.User{
 				Username: "fakeuser" + model.NewRandomString(10),
 				Password: "Pa$$word11",
@@ -1710,3 +1621,254 @@ func (s *MmctlE2ETestSuite) TestSendPasswordResetEmailCmd() {
 		s.Require().EqualError(err, "expected at least one argument. See help text for details")
 	})
 }
+
+func (s *MmctlE2ETestSuite) TestUserEditUsernameCmd() {
+	s.SetupTestHelper().InitBasic()
+
+	user, appErr := s.th.App.CreateUser(s.th.Context, &model.User{
+		Email:    s.th.GenerateTestEmail(),
+		Username: model.NewUsername(),
+		Password: model.NewId(),
+	})
+	s.Require().Nil(appErr)
+
+	s.RunForSystemAdminAndLocal("Edit username successfully", func(c client.Client) {
+		printer.Clean()
+
+		oldUsername := user.Username
+		newUsername := "editedusername" + model.NewRandomString(5)
+
+		err := userEditUsernameCmdF(c, &cobra.Command{}, []string{user.Username, newUsername})
+		s.Require().Nil(err)
+		s.Require().Len(printer.GetLines(), 1)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify username was updated
+		updatedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(newUsername, updatedUser.Username)
+
+		// Restore original username for next test
+		user.Username = oldUsername
+		_, appErr = s.th.App.UpdateUser(s.th.Context, user, false)
+		s.Require().Nil(appErr)
+	})
+
+	s.Run("Edit username without permission", func() {
+		printer.Clean()
+
+		newUsername := "unauthorizedusername"
+
+		err := userEditUsernameCmdF(s.th.Client, &cobra.Command{}, []string{user.Username, newUsername})
+		s.Require().Error(err)
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify username was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(user.Username, unchangedUser.Username)
+	})
+
+	s.RunForAllClients("Edit username with invalid username", func(c client.Client) {
+		printer.Clean()
+
+		invalidUsername := "invalid username with spaces"
+
+		err := userEditUsernameCmdF(c, &cobra.Command{}, []string{user.Username, invalidUsername})
+		s.Require().Error(err)
+		s.Require().EqualError(err, "invalid username: '"+invalidUsername+"'")
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify username was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(user.Username, unchangedUser.Username)
+	})
+
+	s.RunForAllClients("Edit username for nonexistent user", func(c client.Client) {
+		printer.Clean()
+
+		nonexistentUser := "nonexistentuser"
+		newUsername := "newusername"
+
+		err := userEditUsernameCmdF(c, &cobra.Command{}, []string{nonexistentUser, newUsername})
+		s.Require().Error(err)
+		s.Require().EqualError(err, "user "+nonexistentUser+" not found")
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+	})
+}
+
+func (s *MmctlE2ETestSuite) TestUserEditEmailCmd() {
+	s.SetupTestHelper().InitBasic()
+
+	user, appErr := s.th.App.CreateUser(s.th.Context, &model.User{
+		Email:    s.th.GenerateTestEmail(),
+		Username: model.NewUsername(),
+		Password: model.NewId(),
+	})
+	s.Require().Nil(appErr)
+
+	s.RunForSystemAdminAndLocal("Edit email successfully", func(c client.Client) {
+		printer.Clean()
+
+		oldEmail := user.Email
+		newEmail := "newemail" + model.NewRandomString(5) + "@example.com"
+
+		err := userEditEmailCmdF(c, &cobra.Command{}, []string{user.Username, newEmail})
+		s.Require().Nil(err)
+		s.Require().Len(printer.GetLines(), 1)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify email was updated
+		updatedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(newEmail, updatedUser.Email)
+
+		// Restore original email for next test
+		user.Email = oldEmail
+		_, appErr = s.th.App.UpdateUser(s.th.Context, user, false)
+		s.Require().Nil(appErr)
+	})
+
+	s.Run("Edit email without permission", func() {
+		printer.Clean()
+
+		newEmail := "unauthorized@example.com"
+
+		err := userEditEmailCmdF(s.th.Client, &cobra.Command{}, []string{user.Username, newEmail})
+		s.Require().Error(err)
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify email was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(user.Email, unchangedUser.Email)
+	})
+
+	s.RunForAllClients("Edit email with invalid email", func(c client.Client) {
+		printer.Clean()
+
+		invalidEmail := "invalidemail"
+
+		err := userEditEmailCmdF(c, &cobra.Command{}, []string{user.Username, invalidEmail})
+		s.Require().Error(err)
+		s.Require().EqualError(err, "invalid email: '"+invalidEmail+"'")
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify email was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().Equal(user.Email, unchangedUser.Email)
+	})
+
+	s.RunForAllClients("Edit email for nonexistent user", func(c client.Client) {
+		printer.Clean()
+
+		nonexistentUser := "nonexistentuser"
+		newEmail := "newemail@example.com"
+
+		err := userEditEmailCmdF(c, &cobra.Command{}, []string{nonexistentUser, newEmail})
+		s.Require().Error(err)
+		s.Require().EqualError(err, "user "+nonexistentUser+" not found")
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+	})
+}
+
+func (s *MmctlE2ETestSuite) TestUserEditAuthdataCmd() {
+	s.SetupTestHelper().InitBasic()
+
+	user, appErr := s.th.App.CreateUser(s.th.Context, &model.User{
+		Email:       s.th.GenerateTestEmail(),
+		Username:    model.NewUsername(),
+		AuthData:    model.NewPointer("existingauthdata"),
+		AuthService: model.UserAuthServiceLdap,
+	})
+	s.Require().Nil(appErr)
+
+	newAuthdata := "newauthdata123"
+
+	s.Run("Edit authdata without permission", func() {
+		printer.Clean()
+
+		err := userEditAuthdataCmdF(s.th.Client, &cobra.Command{}, []string{user.Username, newAuthdata})
+		s.Require().Error(err)
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify authdata was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().NotNil(unchangedUser.AuthData)
+		s.Require().Equal("existingauthdata", *unchangedUser.AuthData)
+	})
+
+	s.RunForSystemAdminAndLocal("Clear authdata returns error", func(c client.Client) {
+		printer.Clean()
+
+		// Attempt to clear authdata with empty string should return error
+		err := userEditAuthdataCmdF(c, &cobra.Command{}, []string{user.Username, ""})
+		s.Require().Error(err)
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify authdata was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().NotNil(unchangedUser.AuthData)
+		s.Require().Equal("existingauthdata", *unchangedUser.AuthData)
+	})
+
+	s.RunForSystemAdminAndLocal("Edit authdata with too long value", func(c client.Client) {
+		printer.Clean()
+
+		// Create authdata longer than maximum allowed length
+		longAuthdata := make([]byte, model.UserAuthDataMaxLength+1)
+		for i := range longAuthdata {
+			longAuthdata[i] = 'a'
+		}
+
+		err := userEditAuthdataCmdF(c, &cobra.Command{}, []string{user.Username, string(longAuthdata)})
+		s.Require().Error(err)
+		s.Require().EqualError(err, fmt.Sprintf("authdata too long. Maximum length is %d characters", model.UserAuthDataMaxLength))
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify authdata was not changed
+		unchangedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().NotNil(unchangedUser.AuthData)
+		s.Require().Equal("existingauthdata", *unchangedUser.AuthData)
+	})
+
+	s.RunForSystemAdminAndLocal("Edit authdata for nonexistent user", func(c client.Client) {
+		printer.Clean()
+
+		nonexistentUser := "nonexistentuser"
+
+		err := userEditAuthdataCmdF(c, &cobra.Command{}, []string{nonexistentUser, newAuthdata})
+		s.Require().Error(err)
+		s.Require().EqualError(err, "user "+nonexistentUser+" not found")
+		s.Require().Len(printer.GetLines(), 0)
+		s.Require().Len(printer.GetErrorLines(), 0)
+	})
+	s.RunForSystemAdminAndLocal("Edit authdata successfully", func(c client.Client) {
+		printer.Clean()
+
+		err := userEditAuthdataCmdF(c, &cobra.Command{}, []string{user.Username, newAuthdata})
+		s.Require().Nil(err)
+		s.Require().Len(printer.GetLines(), 1)
+		s.Require().Len(printer.GetErrorLines(), 0)
+
+		// Verify authdata was updated
+		updatedUser, appErr := s.th.App.GetUser(user.Id)
+		s.Require().Nil(appErr)
+		s.Require().NotNil(updatedUser.AuthData)
+		s.Require().Equal(newAuthdata, *updatedUser.AuthData)
+	})
+}
