@@ -17,14 +17,9 @@ func (seb *Broker) RegisterElasticsearchEngine(es SearchEngineInterface) {
 	seb.ElasticsearchEngine = es
 }
 
-func (seb *Broker) RegisterBleveEngine(be SearchEngineInterface) {
-	seb.BleveEngine = be
-}
-
 type Broker struct {
 	cfg                 *model.Config
 	ElasticsearchEngine SearchEngineInterface
-	BleveEngine         SearchEngineInterface
 }
 
 func (seb *Broker) UpdateConfig(cfg *model.Config) *model.AppError {
@@ -33,10 +28,6 @@ func (seb *Broker) UpdateConfig(cfg *model.Config) *model.AppError {
 		seb.ElasticsearchEngine.UpdateConfig(cfg)
 	}
 
-	if seb.BleveEngine != nil {
-		seb.BleveEngine.UpdateConfig(cfg)
-	}
-
 	return nil
 }
 
@@ -45,9 +36,6 @@ func (seb *Broker) GetActiveEngines() []SearchEngineInterface {
 	if seb.ElasticsearchEngine != nil && seb.ElasticsearchEngine.IsActive() {
 		engines = append(engines, seb.ElasticsearchEngine)
 	}
-	if seb.BleveEngine != nil && seb.BleveEngine.IsActive() && seb.BleveEngine.IsIndexingEnabled() {
-		engines = append(engines, seb.BleveEngine)
-	}
 	return engines
 }
 
