@@ -531,7 +531,7 @@ func TestRewriteImageURLs(t *testing.T) {
 var rewriteImageURLsSink string
 
 func BenchmarkRewriteImageURLs(b *testing.B) {
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		rewriteImageURLsSink = RewriteImageURLs(markdownSample, func(url string) string {
 			return "rewritten:" + url
 		})
@@ -573,7 +573,7 @@ func TestPostClone(t *testing.T) {
 
 func BenchmarkClonePost(b *testing.B) {
 	p := Post{}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = p.Clone()
 	}
 }
@@ -582,7 +582,7 @@ func BenchmarkPostPropsGet_indirect(b *testing.B) {
 	p := Post{
 		Props: make(StringInterface),
 	}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = p.GetProps()
 	}
 }
@@ -591,7 +591,7 @@ func BenchmarkPostPropsGet_direct(b *testing.B) {
 	p := Post{
 		Props: make(StringInterface),
 	}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = p.Props
 	}
 }
@@ -600,7 +600,7 @@ func BenchmarkPostPropsAdd_indirect(b *testing.B) {
 	p := Post{
 		Props: make(StringInterface),
 	}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		p.AddProp("test", "somevalue")
 	}
 }
@@ -609,7 +609,7 @@ func BenchmarkPostPropsAdd_direct(b *testing.B) {
 	p := Post{
 		Props: make(StringInterface),
 	}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		p.Props["test"] = "somevalue"
 	}
 }
@@ -619,7 +619,7 @@ func BenchmarkPostPropsDel_indirect(b *testing.B) {
 		Props: make(StringInterface),
 	}
 	p.AddProp("test", "somevalue")
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		p.DelProp("test")
 	}
 }
@@ -628,7 +628,7 @@ func BenchmarkPostPropsDel_direct(b *testing.B) {
 	p := Post{
 		Props: make(StringInterface),
 	}
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		delete(p.Props, "test")
 	}
 }
@@ -638,7 +638,7 @@ func BenchmarkPostPropGet_direct(b *testing.B) {
 		Props: make(StringInterface),
 	}
 	p.Props["somekey"] = "somevalue"
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = p.Props["somekey"]
 	}
 }
@@ -648,7 +648,7 @@ func BenchmarkPostPropGet_indirect(b *testing.B) {
 		Props: make(StringInterface),
 	}
 	p.Props["somekey"] = "somevalue"
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_ = p.GetProp("somekey")
 	}
 }
@@ -662,49 +662,49 @@ func TestPostPropsDataRace(t *testing.T) {
 	wg.Add(7)
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			p.AddProp("test", "test")
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			_ = p.GetProp("test")
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			p.AddProp("test", "test2")
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			_ = p.GetProps()["test"]
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			p.DelProp("test")
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			p.SetProps(make(StringInterface))
 		}
 		wg.Done()
 	}()
 
 	go func() {
-		for i := 0; i < 100; i++ {
+		for range 100 {
 			_ = p.Clone()
 		}
 		wg.Done()
