@@ -163,11 +163,6 @@ func init() {
 		PermissionSysconsoleReadComplianceComplianceMonitoring.Id: {
 			PermissionReadAudits,
 		},
-		PermissionSysconsoleWriteExperimentalBleve.Id: {
-			PermissionCreatePostBleveIndexesJob,
-			PermissionPurgeBleveIndexes,
-			PermissionManagePostBleveIndexesJob,
-		},
 		PermissionSysconsoleWriteAuthenticationLdap.Id: {
 			PermissionCreateLdapSyncJob,
 			PermissionManageLdapSyncJob,
@@ -265,7 +260,6 @@ func init() {
 		PermissionSysconsoleReadComplianceCustomTermsOfService.Id,
 		PermissionSysconsoleReadExperimentalFeatures.Id,
 		PermissionSysconsoleReadExperimentalFeatureFlags.Id,
-		PermissionSysconsoleReadExperimentalBleve.Id,
 		PermissionSysconsoleReadProductsBoards.Id,
 	}
 
@@ -916,6 +910,7 @@ func MakeDefaultRoles() map[string]*Role {
 			PermissionOrderBookmarkPrivateChannel.Id,
 			PermissionManagePublicChannelBanner.Id,
 			PermissionManagePrivateChannelBanner.Id,
+			PermissionManageChannelAccessRules.Id,
 		},
 		SchemeManaged: true,
 		BuiltIn:       true,
@@ -1004,6 +999,7 @@ func MakeDefaultRoles() map[string]*Role {
 			PermissionOrderBookmarkPrivateChannel.Id,
 			PermissionManagePublicChannelBanner.Id,
 			PermissionManagePrivateChannelBanner.Id,
+			PermissionManageChannelAccessRules.Id,
 		},
 		SchemeManaged: true,
 		BuiltIn:       true,
