@@ -98,6 +98,7 @@ const (
 	WebsocketEventCPAFieldUpdated                     WebsocketEventType = "custom_profile_attributes_field_updated"
 	WebsocketEventCPAFieldDeleted                     WebsocketEventType = "custom_profile_attributes_field_deleted"
 	WebsocketEventCPAValuesUpdated                    WebsocketEventType = "custom_profile_attributes_values_updated"
+	WebsocketContentFlaggingReportValueUpdated        WebsocketEventType = "content_flagging_report_value_updated"
 
 	WebSocketMsgTypeResponse = "response"
 	WebSocketMsgTypeEvent    = "event"
@@ -153,9 +154,7 @@ func (wb *WebsocketBroadcast) copy() *WebsocketBroadcast {
 	var c WebsocketBroadcast
 	if wb.OmitUsers != nil {
 		c.OmitUsers = make(map[string]bool, len(wb.OmitUsers))
-		for k, v := range wb.OmitUsers {
-			c.OmitUsers[k] = v
-		}
+		maps.Copy(c.OmitUsers, wb.OmitUsers)
 	}
 	c.UserId = wb.UserId
 	c.ChannelId = wb.ChannelId
